# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'wizzard_main_ui.ui'
#
# Created by: PyQt5 UI code generator 5.8.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_WizzardMainDialog(object):
    def setupUi(self, WizzardMainDialog):
        WizzardMainDialog.setObjectName("WizzardMainDialog")
        WizzardMainDialog.setWindowModality(QtCore.Qt.NonModal)
        WizzardMainDialog.setEnabled(True)
        WizzardMainDialog.resize(790, 670)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(WizzardMainDialog.sizePolicy().hasHeightForWidth())
        WizzardMainDialog.setSizePolicy(sizePolicy)
        WizzardMainDialog.setMinimumSize(QtCore.QSize(0, 45))
        WizzardMainDialog.setMaximumSize(QtCore.QSize(16777179, 16777215))
        WizzardMainDialog.setSizeIncrement(QtCore.QSize(9, 0))
        font = QtGui.QFont()
        font.setFamily("MS Shell Dlg 2")
        font.setPointSize(8)
        font.setBold(False)
        font.setWeight(50)
        WizzardMainDialog.setFont(font)
        WizzardMainDialog.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        WizzardMainDialog.setFocusPolicy(QtCore.Qt.NoFocus)
        WizzardMainDialog.setContextMenuPolicy(QtCore.Qt.PreventContextMenu)
        WizzardMainDialog.setToolTipDuration(6)
        WizzardMainDialog.setAutoFillBackground(True)
        self.le_mountStatus = QtWidgets.QLineEdit(WizzardMainDialog)
        self.le_mountStatus.setGeometry(QtCore.QRect(10, 80, 341, 21))
        font = QtGui.QFont()
        font.setFamily("MS Shell Dlg 2")
        font.setPointSize(10)
        font.setBold(False)
        font.setWeight(50)
        self.le_mountStatus.setFont(font)
        self.le_mountStatus.setMouseTracking(False)
        self.le_mountStatus.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_mountStatus.setAcceptDrops(False)
        self.le_mountStatus.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.le_mountStatus.setReadOnly(True)
        self.le_mountStatus.setObjectName("le_mountStatus")
        self.tabWidget = QtWidgets.QTabWidget(WizzardMainDialog)
        self.tabWidget.setGeometry(QtCore.QRect(10, 150, 771, 511))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.tabWidget.setFont(font)
        self.tabWidget.setObjectName("tabWidget")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.le_telescopeRA = QtWidgets.QLineEdit(self.tab_2)
        self.le_telescopeRA.setGeometry(QtCore.QRect(10, 140, 191, 41))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(24)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopeRA.setFont(font)
        self.le_telescopeRA.setMouseTracking(False)
        self.le_telescopeRA.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_telescopeRA.setAcceptDrops(False)
        self.le_telescopeRA.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopeRA.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_telescopeRA.setReadOnly(True)
        self.le_telescopeRA.setObjectName("le_telescopeRA")
        self.le_telescopeAzimut = QtWidgets.QLineEdit(self.tab_2)
        self.le_telescopeAzimut.setGeometry(QtCore.QRect(10, 70, 191, 41))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(24)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopeAzimut.setFont(font)
        self.le_telescopeAzimut.setMouseTracking(False)
        self.le_telescopeAzimut.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_telescopeAzimut.setAcceptDrops(False)
        self.le_telescopeAzimut.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopeAzimut.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_telescopeAzimut.setReadOnly(True)
        self.le_telescopeAzimut.setObjectName("le_telescopeAzimut")
        self.le_telescopeDEC = QtWidgets.QLineEdit(self.tab_2)
        self.le_telescopeDEC.setGeometry(QtCore.QRect(230, 140, 191, 41))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(24)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopeDEC.setFont(font)
        self.le_telescopeDEC.setMouseTracking(False)
        self.le_telescopeDEC.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_telescopeDEC.setAcceptDrops(False)
        self.le_telescopeDEC.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopeDEC.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_telescopeDEC.setReadOnly(True)
        self.le_telescopeDEC.setObjectName("le_telescopeDEC")
        self.le_telescopeAltitude = QtWidgets.QLineEdit(self.tab_2)
        self.le_telescopeAltitude.setGeometry(QtCore.QRect(230, 70, 191, 41))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(24)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopeAltitude.setFont(font)
        self.le_telescopeAltitude.setMouseTracking(False)
        self.le_telescopeAltitude.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_telescopeAltitude.setAcceptDrops(False)
        self.le_telescopeAltitude.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopeAltitude.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_telescopeAltitude.setReadOnly(True)
        self.le_telescopeAltitude.setObjectName("le_telescopeAltitude")
        self.label_9 = QtWidgets.QLabel(self.tab_2)
        self.label_9.setGeometry(QtCore.QRect(10, 50, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_9.setFont(font)
        self.label_9.setObjectName("label_9")
        self.label_10 = QtWidgets.QLabel(self.tab_2)
        self.label_10.setGeometry(QtCore.QRect(230, 120, 131, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_10.setFont(font)
        self.label_10.setObjectName("label_10")
        self.label_8 = QtWidgets.QLabel(self.tab_2)
        self.label_8.setGeometry(QtCore.QRect(230, 50, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_8.setFont(font)
        self.label_8.setObjectName("label_8")
        self.label_11 = QtWidgets.QLabel(self.tab_2)
        self.label_11.setGeometry(QtCore.QRect(10, 120, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_11.setFont(font)
        self.label_11.setObjectName("label_11")
        self.label_17 = QtWidgets.QLabel(self.tab_2)
        self.label_17.setGeometry(QtCore.QRect(10, 240, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_17.setFont(font)
        self.label_17.setObjectName("label_17")
        self.le_meridianLimitTrack = QtWidgets.QLineEdit(self.tab_2)
        self.le_meridianLimitTrack.setGeometry(QtCore.QRect(140, 330, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_meridianLimitTrack.setFont(font)
        self.le_meridianLimitTrack.setMouseTracking(False)
        self.le_meridianLimitTrack.setAcceptDrops(False)
        self.le_meridianLimitTrack.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_meridianLimitTrack.setCursorPosition(2)
        self.le_meridianLimitTrack.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_meridianLimitTrack.setReadOnly(True)
        self.le_meridianLimitTrack.setObjectName("le_meridianLimitTrack")
        self.le_telescopePierSide = QtWidgets.QLineEdit(self.tab_2)
        self.le_telescopePierSide.setGeometry(QtCore.QRect(320, 240, 61, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopePierSide.setFont(font)
        self.le_telescopePierSide.setMouseTracking(False)
        self.le_telescopePierSide.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_telescopePierSide.setAcceptDrops(False)
        self.le_telescopePierSide.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopePierSide.setAlignment(QtCore.Qt.AlignCenter)
        self.le_telescopePierSide.setReadOnly(True)
        self.le_telescopePierSide.setObjectName("le_telescopePierSide")
        self.label_18 = QtWidgets.QLabel(self.tab_2)
        self.label_18.setGeometry(QtCore.QRect(230, 240, 71, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_18.setFont(font)
        self.label_18.setObjectName("label_18")
        self.label_21 = QtWidgets.QLabel(self.tab_2)
        self.label_21.setGeometry(QtCore.QRect(10, 270, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_21.setFont(font)
        self.label_21.setObjectName("label_21")
        self.le_telescopeDualTrack = QtWidgets.QLineEdit(self.tab_2)
        self.le_telescopeDualTrack.setGeometry(QtCore.QRect(120, 270, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopeDualTrack.setFont(font)
        self.le_telescopeDualTrack.setMouseTracking(False)
        self.le_telescopeDualTrack.setAcceptDrops(False)
        self.le_telescopeDualTrack.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopeDualTrack.setInputMask("")
        self.le_telescopeDualTrack.setAlignment(QtCore.Qt.AlignCenter)
        self.le_telescopeDualTrack.setReadOnly(True)
        self.le_telescopeDualTrack.setObjectName("le_telescopeDualTrack")
        self.btn_setDualTracking = QtWidgets.QPushButton(self.tab_2)
        self.btn_setDualTracking.setGeometry(QtCore.QRect(170, 270, 31, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setDualTracking.setFont(font)
        self.btn_setDualTracking.setObjectName("btn_setDualTracking")
        self.label_52 = QtWidgets.QLabel(self.tab_2)
        self.label_52.setGeometry(QtCore.QRect(230, 330, 91, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_52.setFont(font)
        self.label_52.setWordWrap(False)
        self.label_52.setObjectName("label_52")
        self.le_timeToFlip = QtWidgets.QLineEdit(self.tab_2)
        self.le_timeToFlip.setGeometry(QtCore.QRect(340, 330, 51, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_timeToFlip.setFont(font)
        self.le_timeToFlip.setMouseTracking(False)
        self.le_timeToFlip.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_timeToFlip.setAcceptDrops(False)
        self.le_timeToFlip.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_timeToFlip.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_timeToFlip.setReadOnly(True)
        self.le_timeToFlip.setObjectName("le_timeToFlip")
        self.btn_setUnattendedFlip = QtWidgets.QPushButton(self.tab_2)
        self.btn_setUnattendedFlip.setGeometry(QtCore.QRect(170, 300, 31, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setUnattendedFlip.setFont(font)
        self.btn_setUnattendedFlip.setObjectName("btn_setUnattendedFlip")
        self.le_telescopeUnattendedFlip = QtWidgets.QLineEdit(self.tab_2)
        self.le_telescopeUnattendedFlip.setGeometry(QtCore.QRect(120, 300, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopeUnattendedFlip.setFont(font)
        self.le_telescopeUnattendedFlip.setMouseTracking(False)
        self.le_telescopeUnattendedFlip.setAcceptDrops(False)
        self.le_telescopeUnattendedFlip.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopeUnattendedFlip.setInputMask("")
        self.le_telescopeUnattendedFlip.setAlignment(QtCore.Qt.AlignCenter)
        self.le_telescopeUnattendedFlip.setReadOnly(True)
        self.le_telescopeUnattendedFlip.setObjectName("le_telescopeUnattendedFlip")
        self.label_23 = QtWidgets.QLabel(self.tab_2)
        self.label_23.setGeometry(QtCore.QRect(10, 300, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_23.setFont(font)
        self.label_23.setObjectName("label_23")
        self.label_61 = QtWidgets.QLabel(self.tab_2)
        self.label_61.setGeometry(QtCore.QRect(390, 330, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_61.setFont(font)
        self.label_61.setAlignment(QtCore.Qt.AlignCenter)
        self.label_61.setWordWrap(False)
        self.label_61.setObjectName("label_61")
        self.label_62 = QtWidgets.QLabel(self.tab_2)
        self.label_62.setGeometry(QtCore.QRect(170, 240, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_62.setFont(font)
        self.label_62.setAlignment(QtCore.Qt.AlignCenter)
        self.label_62.setWordWrap(False)
        self.label_62.setObjectName("label_62")
        self.label_80 = QtWidgets.QLabel(self.tab_2)
        self.label_80.setGeometry(QtCore.QRect(10, 210, 211, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_80.setFont(font)
        self.label_80.setObjectName("label_80")
        self.line_12 = QtWidgets.QFrame(self.tab_2)
        self.line_12.setGeometry(QtCore.QRect(10, 220, 411, 21))
        self.line_12.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_12.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_12.setObjectName("line_12")
        self.line_13 = QtWidgets.QFrame(self.tab_2)
        self.line_13.setGeometry(QtCore.QRect(10, 30, 411, 21))
        self.line_13.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_13.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_13.setObjectName("line_13")
        self.label_81 = QtWidgets.QLabel(self.tab_2)
        self.label_81.setGeometry(QtCore.QRect(10, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_81.setFont(font)
        self.label_81.setObjectName("label_81")
        self.btn_startTracking = QtWidgets.QPushButton(self.tab_2)
        self.btn_startTracking.setGeometry(QtCore.QRect(450, 210, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_startTracking.setFont(font)
        self.btn_startTracking.setObjectName("btn_startTracking")
        self.btn_mountPark = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountPark.setGeometry(QtCore.QRect(450, 330, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountPark.setFont(font)
        self.btn_mountPark.setObjectName("btn_mountPark")
        self.btn_mountUnpark = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountUnpark.setGeometry(QtCore.QRect(600, 330, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountUnpark.setFont(font)
        self.btn_mountUnpark.setObjectName("btn_mountUnpark")
        self.line_16 = QtWidgets.QFrame(self.tab_2)
        self.line_16.setGeometry(QtCore.QRect(450, 310, 291, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_16.setFont(font)
        self.line_16.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_16.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_16.setObjectName("line_16")
        self.label_83 = QtWidgets.QLabel(self.tab_2)
        self.label_83.setGeometry(QtCore.QRect(450, 20, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_83.setFont(font)
        self.label_83.setObjectName("label_83")
        self.label_84 = QtWidgets.QLabel(self.tab_2)
        self.label_84.setGeometry(QtCore.QRect(450, 180, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_84.setFont(font)
        self.label_84.setObjectName("label_84")
        self.btn_mountPos4 = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountPos4.setGeometry(QtCore.QRect(600, 90, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountPos4.setFont(font)
        self.btn_mountPos4.setObjectName("btn_mountPos4")
        self.line_15 = QtWidgets.QFrame(self.tab_2)
        self.line_15.setGeometry(QtCore.QRect(450, 190, 291, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_15.setFont(font)
        self.line_15.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_15.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_15.setObjectName("line_15")
        self.label_85 = QtWidgets.QLabel(self.tab_2)
        self.label_85.setGeometry(QtCore.QRect(450, 300, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_85.setFont(font)
        self.label_85.setObjectName("label_85")
        self.btn_mountPos2 = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountPos2.setGeometry(QtCore.QRect(600, 50, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountPos2.setFont(font)
        self.btn_mountPos2.setObjectName("btn_mountPos2")
        self.btn_mountPos3 = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountPos3.setGeometry(QtCore.QRect(450, 90, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountPos3.setFont(font)
        self.btn_mountPos3.setObjectName("btn_mountPos3")
        self.btn_mountPos1 = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountPos1.setGeometry(QtCore.QRect(450, 50, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountPos1.setFont(font)
        self.btn_mountPos1.setObjectName("btn_mountPos1")
        self.btn_stopTracking = QtWidgets.QPushButton(self.tab_2)
        self.btn_stopTracking.setGeometry(QtCore.QRect(600, 210, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_stopTracking.setFont(font)
        self.btn_stopTracking.setObjectName("btn_stopTracking")
        self.line_14 = QtWidgets.QFrame(self.tab_2)
        self.line_14.setGeometry(QtCore.QRect(450, 30, 291, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_14.setFont(font)
        self.line_14.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_14.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_14.setObjectName("line_14")
        self.btn_stop = QtWidgets.QPushButton(self.tab_2)
        self.btn_stop.setGeometry(QtCore.QRect(450, 370, 291, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_stop.setFont(font)
        self.btn_stop.setObjectName("btn_stop")
        self.btn_flipMount = QtWidgets.QPushButton(self.tab_2)
        self.btn_flipMount.setGeometry(QtCore.QRect(230, 270, 191, 51))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_flipMount.setFont(font)
        self.btn_flipMount.setObjectName("btn_flipMount")
        self.btn_setTrackingLunar = QtWidgets.QPushButton(self.tab_2)
        self.btn_setTrackingLunar.setGeometry(QtCore.QRect(450, 250, 91, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setTrackingLunar.setFont(font)
        self.btn_setTrackingLunar.setObjectName("btn_setTrackingLunar")
        self.btn_setTrackingSolar = QtWidgets.QPushButton(self.tab_2)
        self.btn_setTrackingSolar.setGeometry(QtCore.QRect(550, 250, 91, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setTrackingSolar.setFont(font)
        self.btn_setTrackingSolar.setObjectName("btn_setTrackingSolar")
        self.btn_setTrackingSideral = QtWidgets.QPushButton(self.tab_2)
        self.btn_setTrackingSideral.setGeometry(QtCore.QRect(650, 250, 91, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setTrackingSideral.setFont(font)
        self.btn_setTrackingSideral.setObjectName("btn_setTrackingSideral")
        self.label_100 = QtWidgets.QLabel(self.tab_2)
        self.label_100.setGeometry(QtCore.QRect(380, 240, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_100.setFont(font)
        self.label_100.setAlignment(QtCore.Qt.AlignCenter)
        self.label_100.setWordWrap(False)
        self.label_100.setObjectName("label_100")
        self.label_34 = QtWidgets.QLabel(self.tab_2)
        self.label_34.setGeometry(QtCore.QRect(10, 330, 141, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_34.setFont(font)
        self.label_34.setObjectName("label_34")
        self.label_65 = QtWidgets.QLabel(self.tab_2)
        self.label_65.setGeometry(QtCore.QRect(10, 360, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_65.setFont(font)
        self.label_65.setObjectName("label_65")
        self.le_meridianLimitSlew = QtWidgets.QLineEdit(self.tab_2)
        self.le_meridianLimitSlew.setGeometry(QtCore.QRect(140, 360, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_meridianLimitSlew.setFont(font)
        self.le_meridianLimitSlew.setMouseTracking(False)
        self.le_meridianLimitSlew.setAcceptDrops(False)
        self.le_meridianLimitSlew.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_meridianLimitSlew.setCursorPosition(2)
        self.le_meridianLimitSlew.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_meridianLimitSlew.setReadOnly(True)
        self.le_meridianLimitSlew.setObjectName("le_meridianLimitSlew")
        self.label_88 = QtWidgets.QLabel(self.tab_2)
        self.label_88.setGeometry(QtCore.QRect(180, 330, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_88.setFont(font)
        self.label_88.setAlignment(QtCore.Qt.AlignCenter)
        self.label_88.setWordWrap(False)
        self.label_88.setObjectName("label_88")
        self.label_89 = QtWidgets.QLabel(self.tab_2)
        self.label_89.setGeometry(QtCore.QRect(180, 360, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_89.setFont(font)
        self.label_89.setAlignment(QtCore.Qt.AlignCenter)
        self.label_89.setWordWrap(False)
        self.label_89.setObjectName("label_89")
        self.le_slewRate = QtWidgets.QLineEdit(self.tab_2)
        self.le_slewRate.setGeometry(QtCore.QRect(120, 240, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_slewRate.setFont(font)
        self.le_slewRate.setMouseTracking(False)
        self.le_slewRate.setAcceptDrops(False)
        self.le_slewRate.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_slewRate.setCursorPosition(2)
        self.le_slewRate.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_slewRate.setReadOnly(True)
        self.le_slewRate.setObjectName("le_slewRate")
        self.label_90 = QtWidgets.QLabel(self.tab_2)
        self.label_90.setGeometry(QtCore.QRect(230, 360, 101, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_90.setFont(font)
        self.label_90.setWordWrap(False)
        self.label_90.setObjectName("label_90")
        self.le_timeToMeridian = QtWidgets.QLineEdit(self.tab_2)
        self.le_timeToMeridian.setGeometry(QtCore.QRect(340, 360, 51, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_timeToMeridian.setFont(font)
        self.le_timeToMeridian.setMouseTracking(False)
        self.le_timeToMeridian.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_timeToMeridian.setAcceptDrops(False)
        self.le_timeToMeridian.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_timeToMeridian.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_timeToMeridian.setReadOnly(True)
        self.le_timeToMeridian.setObjectName("le_timeToMeridian")
        self.label_91 = QtWidgets.QLabel(self.tab_2)
        self.label_91.setGeometry(QtCore.QRect(390, 360, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_91.setFont(font)
        self.label_91.setAlignment(QtCore.Qt.AlignCenter)
        self.label_91.setWordWrap(False)
        self.label_91.setObjectName("label_91")
        self.btn_mountPos6 = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountPos6.setGeometry(QtCore.QRect(600, 130, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountPos6.setFont(font)
        self.btn_mountPos6.setObjectName("btn_mountPos6")
        self.btn_mountPos5 = QtWidgets.QPushButton(self.tab_2)
        self.btn_mountPos5.setGeometry(QtCore.QRect(450, 130, 141, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountPos5.setFont(font)
        self.btn_mountPos5.setObjectName("btn_mountPos5")
        self.tabWidget.addTab(self.tab_2, "")
        self.tab_6 = QtWidgets.QWidget()
        self.tab_6.setObjectName("tab_6")
        self.btn_runBaseModel = QtWidgets.QPushButton(self.tab_6)
        self.btn_runBaseModel.setGeometry(QtCore.QRect(10, 400, 131, 31))
        self.btn_runBaseModel.setObjectName("btn_runBaseModel")
        self.checkUseBlindSolve = QtWidgets.QCheckBox(self.tab_6)
        self.checkUseBlindSolve.setGeometry(QtCore.QRect(10, 220, 131, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkUseBlindSolve.setFont(font)
        self.checkUseBlindSolve.setObjectName("checkUseBlindSolve")
        self.btn_clearAlignmentModel = QtWidgets.QPushButton(self.tab_6)
        self.btn_clearAlignmentModel.setGeometry(QtCore.QRect(490, 310, 251, 31))
        self.btn_clearAlignmentModel.setObjectName("btn_clearAlignmentModel")
        self.btn_loadBasePoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_loadBasePoints.setGeometry(QtCore.QRect(10, 50, 131, 31))
        self.btn_loadBasePoints.setObjectName("btn_loadBasePoints")
        self.line_24 = QtWidgets.QFrame(self.tab_6)
        self.line_24.setGeometry(QtCore.QRect(10, 190, 131, 21))
        self.line_24.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_24.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_24.setObjectName("line_24")
        self.btn_generateBasePoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_generateBasePoints.setGeometry(QtCore.QRect(10, 100, 131, 31))
        self.btn_generateBasePoints.setObjectName("btn_generateBasePoints")
        self.azimuthBase = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.azimuthBase.setGeometry(QtCore.QRect(70, 170, 51, 22))
        self.azimuthBase.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.azimuthBase.setDecimals(0)
        self.azimuthBase.setMaximum(120.0)
        self.azimuthBase.setSingleStep(1.0)
        self.azimuthBase.setProperty("value", 120.0)
        self.azimuthBase.setObjectName("azimuthBase")
        self.altitudeBase = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.altitudeBase.setGeometry(QtCore.QRect(70, 140, 51, 22))
        self.altitudeBase.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.altitudeBase.setDecimals(0)
        self.altitudeBase.setMinimum(20.0)
        self.altitudeBase.setMaximum(70.0)
        self.altitudeBase.setSingleStep(1.0)
        self.altitudeBase.setProperty("value", 70.0)
        self.altitudeBase.setObjectName("altitudeBase")
        self.label_170 = QtWidgets.QLabel(self.tab_6)
        self.label_170.setGeometry(QtCore.QRect(10, 140, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_170.setFont(font)
        self.label_170.setObjectName("label_170")
        self.label_171 = QtWidgets.QLabel(self.tab_6)
        self.label_171.setGeometry(QtCore.QRect(10, 170, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_171.setFont(font)
        self.label_171.setObjectName("label_171")
        self.line_23 = QtWidgets.QFrame(self.tab_6)
        self.line_23.setGeometry(QtCore.QRect(10, 350, 131, 21))
        self.line_23.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_23.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_23.setObjectName("line_23")
        self.label_103 = QtWidgets.QLabel(self.tab_6)
        self.label_103.setGeometry(QtCore.QRect(10, 340, 131, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_103.setFont(font)
        self.label_103.setObjectName("label_103")
        self.label_109 = QtWidgets.QLabel(self.tab_6)
        self.label_109.setGeometry(QtCore.QRect(120, 140, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_109.setFont(font)
        self.label_109.setAlignment(QtCore.Qt.AlignCenter)
        self.label_109.setWordWrap(False)
        self.label_109.setObjectName("label_109")
        self.label_110 = QtWidgets.QLabel(self.tab_6)
        self.label_110.setGeometry(QtCore.QRect(120, 170, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_110.setFont(font)
        self.label_110.setAlignment(QtCore.Qt.AlignCenter)
        self.label_110.setWordWrap(False)
        self.label_110.setObjectName("label_110")
        self.label_116 = QtWidgets.QLabel(self.tab_6)
        self.label_116.setGeometry(QtCore.QRect(10, 20, 131, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_116.setFont(font)
        self.label_116.setObjectName("label_116")
        self.line_35 = QtWidgets.QFrame(self.tab_6)
        self.line_35.setGeometry(QtCore.QRect(10, 30, 131, 21))
        self.line_35.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_35.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_35.setObjectName("line_35")
        self.line_36 = QtWidgets.QFrame(self.tab_6)
        self.line_36.setGeometry(QtCore.QRect(10, 240, 131, 21))
        self.line_36.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_36.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_36.setObjectName("line_36")
        self.btn_openCoordinateWindow = QtWidgets.QPushButton(self.tab_6)
        self.btn_openCoordinateWindow.setGeometry(QtCore.QRect(490, 100, 251, 31))
        self.btn_openCoordinateWindow.setObjectName("btn_openCoordinateWindow")
        self.btn_sortRefinementPoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_sortRefinementPoints.setGeometry(QtCore.QRect(490, 260, 251, 31))
        self.btn_sortRefinementPoints.setObjectName("btn_sortRefinementPoints")
        self.btn_generateGridPoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_generateGridPoints.setGeometry(QtCore.QRect(180, 100, 131, 31))
        self.btn_generateGridPoints.setObjectName("btn_generateGridPoints")
        self.label_108 = QtWidgets.QLabel(self.tab_6)
        self.label_108.setGeometry(QtCore.QRect(180, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_108.setFont(font)
        self.label_108.setObjectName("label_108")
        self.label_179 = QtWidgets.QLabel(self.tab_6)
        self.label_179.setGeometry(QtCore.QRect(340, 140, 61, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_179.setFont(font)
        self.label_179.setObjectName("label_179")
        self.label_178 = QtWidgets.QLabel(self.tab_6)
        self.label_178.setGeometry(QtCore.QRect(180, 140, 61, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_178.setFont(font)
        self.label_178.setObjectName("label_178")
        self.btn_generateNormalPoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_generateNormalPoints.setGeometry(QtCore.QRect(320, 180, 131, 31))
        self.btn_generateNormalPoints.setObjectName("btn_generateNormalPoints")
        self.btn_generateDensePoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_generateDensePoints.setGeometry(QtCore.QRect(180, 180, 131, 31))
        self.btn_generateDensePoints.setObjectName("btn_generateDensePoints")
        self.numberGridPointsRow = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.numberGridPointsRow.setGeometry(QtCore.QRect(260, 140, 51, 21))
        self.numberGridPointsRow.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numberGridPointsRow.setDecimals(0)
        self.numberGridPointsRow.setMinimum(3.0)
        self.numberGridPointsRow.setMaximum(10.0)
        self.numberGridPointsRow.setSingleStep(1.0)
        self.numberGridPointsRow.setProperty("value", 5.0)
        self.numberGridPointsRow.setObjectName("numberGridPointsRow")
        self.line_34 = QtWidgets.QFrame(self.tab_6)
        self.line_34.setGeometry(QtCore.QRect(180, 30, 271, 21))
        self.line_34.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_34.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_34.setObjectName("line_34")
        self.line_22 = QtWidgets.QFrame(self.tab_6)
        self.line_22.setGeometry(QtCore.QRect(180, 350, 271, 21))
        self.line_22.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_22.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_22.setObjectName("line_22")
        self.numberGridPointsCol = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.numberGridPointsCol.setGeometry(QtCore.QRect(400, 140, 51, 21))
        self.numberGridPointsCol.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numberGridPointsCol.setDecimals(0)
        self.numberGridPointsCol.setMinimum(5.0)
        self.numberGridPointsCol.setMaximum(15.0)
        self.numberGridPointsCol.setSingleStep(1.0)
        self.numberGridPointsCol.setProperty("value", 10.0)
        self.numberGridPointsCol.setObjectName("numberGridPointsCol")
        self.btn_runRefinementModel = QtWidgets.QPushButton(self.tab_6)
        self.btn_runRefinementModel.setGeometry(QtCore.QRect(180, 400, 271, 31))
        self.btn_runRefinementModel.setObjectName("btn_runRefinementModel")
        self.btn_deleteBelowHorizonLine = QtWidgets.QPushButton(self.tab_6)
        self.btn_deleteBelowHorizonLine.setGeometry(QtCore.QRect(490, 220, 251, 31))
        self.btn_deleteBelowHorizonLine.setObjectName("btn_deleteBelowHorizonLine")
        self.line_26 = QtWidgets.QFrame(self.tab_6)
        self.line_26.setGeometry(QtCore.QRect(180, 210, 271, 21))
        self.line_26.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_26.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_26.setObjectName("line_26")
        self.btn_loadRefinementPoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_loadRefinementPoints.setGeometry(QtCore.QRect(180, 50, 131, 31))
        self.btn_loadRefinementPoints.setObjectName("btn_loadRefinementPoints")
        self.label_101 = QtWidgets.QLabel(self.tab_6)
        self.label_101.setGeometry(QtCore.QRect(180, 340, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_101.setFont(font)
        self.label_101.setObjectName("label_101")
        self.btn_cancelModel = QtWidgets.QPushButton(self.tab_6)
        self.btn_cancelModel.setGeometry(QtCore.QRect(490, 440, 251, 31))
        self.btn_cancelModel.setObjectName("btn_cancelModel")
        self.btn_runCheckModel = QtWidgets.QPushButton(self.tab_6)
        self.btn_runCheckModel.setGeometry(QtCore.QRect(490, 400, 251, 31))
        self.btn_runCheckModel.setObjectName("btn_runCheckModel")
        self.label_98 = QtWidgets.QLabel(self.tab_6)
        self.label_98.setGeometry(QtCore.QRect(490, 370, 251, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_98.setFont(font)
        self.label_98.setObjectName("label_98")
        self.line_32 = QtWidgets.QFrame(self.tab_6)
        self.line_32.setGeometry(QtCore.QRect(490, 380, 251, 21))
        self.line_32.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_32.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_32.setObjectName("line_32")
        self.line_27 = QtWidgets.QFrame(self.tab_6)
        self.line_27.setGeometry(QtCore.QRect(10, 80, 131, 21))
        self.line_27.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_27.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_27.setObjectName("line_27")
        self.line_28 = QtWidgets.QFrame(self.tab_6)
        self.line_28.setGeometry(QtCore.QRect(180, 80, 271, 21))
        self.line_28.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_28.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_28.setObjectName("line_28")
        self.btn_generateDSOPoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_generateDSOPoints.setGeometry(QtCore.QRect(180, 230, 131, 31))
        self.btn_generateDSOPoints.setObjectName("btn_generateDSOPoints")
        self.line_39 = QtWidgets.QFrame(self.tab_6)
        self.line_39.setGeometry(QtCore.QRect(150, 30, 21, 401))
        self.line_39.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_39.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_39.setObjectName("line_39")
        self.line_40 = QtWidgets.QFrame(self.tab_6)
        self.line_40.setGeometry(QtCore.QRect(460, 30, 21, 431))
        self.line_40.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_40.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_40.setObjectName("line_40")
        self.label_113 = QtWidgets.QLabel(self.tab_6)
        self.label_113.setGeometry(QtCore.QRect(490, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_113.setFont(font)
        self.label_113.setObjectName("label_113")
        self.line_41 = QtWidgets.QFrame(self.tab_6)
        self.line_41.setGeometry(QtCore.QRect(490, 30, 251, 21))
        self.line_41.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_41.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_41.setObjectName("line_41")
        self.line_42 = QtWidgets.QFrame(self.tab_6)
        self.line_42.setGeometry(QtCore.QRect(180, 160, 271, 21))
        self.line_42.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_42.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_42.setObjectName("line_42")
        self.btn_deletePoints = QtWidgets.QPushButton(self.tab_6)
        self.btn_deletePoints.setGeometry(QtCore.QRect(490, 180, 251, 31))
        self.btn_deletePoints.setObjectName("btn_deletePoints")
        self.btn_runAllModel = QtWidgets.QPushButton(self.tab_6)
        self.btn_runAllModel.setGeometry(QtCore.QRect(10, 440, 441, 31))
        self.btn_runAllModel.setObjectName("btn_runAllModel")
        self.numberHoursDSO = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.numberHoursDSO.setGeometry(QtCore.QRect(260, 270, 51, 21))
        self.numberHoursDSO.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numberHoursDSO.setDecimals(0)
        self.numberHoursDSO.setMinimum(5.0)
        self.numberHoursDSO.setMaximum(15.0)
        self.numberHoursDSO.setSingleStep(1.0)
        self.numberHoursDSO.setProperty("value", 10.0)
        self.numberHoursDSO.setObjectName("numberHoursDSO")
        self.label_181 = QtWidgets.QLabel(self.tab_6)
        self.label_181.setGeometry(QtCore.QRect(190, 270, 61, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_181.setFont(font)
        self.label_181.setObjectName("label_181")
        self.label_188 = QtWidgets.QLabel(self.tab_6)
        self.label_188.setGeometry(QtCore.QRect(190, 300, 61, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_188.setFont(font)
        self.label_188.setObjectName("label_188")
        self.numberPointsDSO = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.numberPointsDSO.setGeometry(QtCore.QRect(260, 300, 51, 21))
        self.numberPointsDSO.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numberPointsDSO.setDecimals(0)
        self.numberPointsDSO.setMinimum(5.0)
        self.numberPointsDSO.setMaximum(50.0)
        self.numberPointsDSO.setSingleStep(1.0)
        self.numberPointsDSO.setProperty("value", 10.0)
        self.numberPointsDSO.setObjectName("numberPointsDSO")
        self.label_189 = QtWidgets.QLabel(self.tab_6)
        self.label_189.setGeometry(QtCore.QRect(330, 270, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_189.setFont(font)
        self.label_189.setObjectName("label_189")
        self.numberHoursPreview = QtWidgets.QDoubleSpinBox(self.tab_6)
        self.numberHoursPreview.setGeometry(QtCore.QRect(410, 270, 41, 21))
        self.numberHoursPreview.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numberHoursPreview.setDecimals(0)
        self.numberHoursPreview.setMinimum(-12.0)
        self.numberHoursPreview.setMaximum(12.0)
        self.numberHoursPreview.setSingleStep(1.0)
        self.numberHoursPreview.setProperty("value", 0.0)
        self.numberHoursPreview.setObjectName("numberHoursPreview")
        self.checkRunTrackingWidget = QtWidgets.QCheckBox(self.tab_6)
        self.checkRunTrackingWidget.setGeometry(QtCore.QRect(500, 140, 241, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkRunTrackingWidget.setFont(font)
        self.checkRunTrackingWidget.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.checkRunTrackingWidget.setChecked(True)
        self.checkRunTrackingWidget.setObjectName("checkRunTrackingWidget")
        self.btn_plateSolveSync = QtWidgets.QPushButton(self.tab_6)
        self.btn_plateSolveSync.setGeometry(QtCore.QRect(490, 50, 251, 31))
        self.btn_plateSolveSync.setObjectName("btn_plateSolveSync")
        self.checkClearModelFirst = QtWidgets.QCheckBox(self.tab_6)
        self.checkClearModelFirst.setGeometry(QtCore.QRect(20, 370, 121, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkClearModelFirst.setFont(font)
        self.checkClearModelFirst.setChecked(True)
        self.checkClearModelFirst.setObjectName("checkClearModelFirst")
        self.checkKeepRefinement = QtWidgets.QCheckBox(self.tab_6)
        self.checkKeepRefinement.setGeometry(QtCore.QRect(190, 370, 261, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkKeepRefinement.setFont(font)
        self.checkKeepRefinement.setObjectName("checkKeepRefinement")
        self.line_30 = QtWidgets.QFrame(self.tab_6)
        self.line_30.setGeometry(QtCore.QRect(490, 80, 251, 21))
        self.line_30.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_30.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_30.setObjectName("line_30")
        self.line_38 = QtWidgets.QFrame(self.tab_6)
        self.line_38.setGeometry(QtCore.QRect(490, 290, 251, 21))
        self.line_38.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_38.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_38.setObjectName("line_38")
        self.line_45 = QtWidgets.QFrame(self.tab_6)
        self.line_45.setGeometry(QtCore.QRect(490, 160, 251, 21))
        self.line_45.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_45.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_45.setObjectName("line_45")
        self.tabWidget.addTab(self.tab_6, "")
        self.tab_5 = QtWidgets.QWidget()
        self.tab_5.setObjectName("tab_5")
        self.label_107 = QtWidgets.QLabel(self.tab_5)
        self.label_107.setGeometry(QtCore.QRect(10, 20, 191, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_107.setFont(font)
        self.label_107.setObjectName("label_107")
        self.btn_cancelAnalyseModel = QtWidgets.QPushButton(self.tab_5)
        self.btn_cancelAnalyseModel.setGeometry(QtCore.QRect(430, 280, 281, 31))
        self.btn_cancelAnalyseModel.setObjectName("btn_cancelAnalyseModel")
        self.btn_runTimeChangeModel = QtWidgets.QPushButton(self.tab_5)
        self.btn_runTimeChangeModel.setGeometry(QtCore.QRect(10, 110, 291, 31))
        self.btn_runTimeChangeModel.setObjectName("btn_runTimeChangeModel")
        self.line_33 = QtWidgets.QFrame(self.tab_5)
        self.line_33.setGeometry(QtCore.QRect(10, 30, 291, 21))
        self.line_33.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_33.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_33.setObjectName("line_33")
        self.label_174 = QtWidgets.QLabel(self.tab_5)
        self.label_174.setGeometry(QtCore.QRect(10, 50, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_174.setFont(font)
        self.label_174.setObjectName("label_174")
        self.azimuthTimeChange = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.azimuthTimeChange.setGeometry(QtCore.QRect(240, 50, 51, 22))
        self.azimuthTimeChange.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.azimuthTimeChange.setDecimals(0)
        self.azimuthTimeChange.setMaximum(359.0)
        self.azimuthTimeChange.setSingleStep(1.0)
        self.azimuthTimeChange.setProperty("value", 0.0)
        self.azimuthTimeChange.setObjectName("azimuthTimeChange")
        self.label_175 = QtWidgets.QLabel(self.tab_5)
        self.label_175.setGeometry(QtCore.QRect(190, 50, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_175.setFont(font)
        self.label_175.setObjectName("label_175")
        self.altitudeTimeChange = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.altitudeTimeChange.setGeometry(QtCore.QRect(110, 50, 51, 22))
        self.altitudeTimeChange.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.altitudeTimeChange.setDecimals(0)
        self.altitudeTimeChange.setMinimum(0.0)
        self.altitudeTimeChange.setMaximum(90.0)
        self.altitudeTimeChange.setSingleStep(1.0)
        self.altitudeTimeChange.setProperty("value", 45.0)
        self.altitudeTimeChange.setObjectName("altitudeTimeChange")
        self.label_176 = QtWidgets.QLabel(self.tab_5)
        self.label_176.setGeometry(QtCore.QRect(10, 80, 91, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_176.setFont(font)
        self.label_176.setObjectName("label_176")
        self.numberRunsTimeChange = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.numberRunsTimeChange.setGeometry(QtCore.QRect(110, 80, 51, 22))
        self.numberRunsTimeChange.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numberRunsTimeChange.setDecimals(0)
        self.numberRunsTimeChange.setMinimum(10.0)
        self.numberRunsTimeChange.setMaximum(300.0)
        self.numberRunsTimeChange.setSingleStep(1.0)
        self.numberRunsTimeChange.setProperty("value", 30.0)
        self.numberRunsTimeChange.setObjectName("numberRunsTimeChange")
        self.label_111 = QtWidgets.QLabel(self.tab_5)
        self.label_111.setGeometry(QtCore.QRect(290, 50, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_111.setFont(font)
        self.label_111.setAlignment(QtCore.Qt.AlignCenter)
        self.label_111.setWordWrap(False)
        self.label_111.setObjectName("label_111")
        self.label_112 = QtWidgets.QLabel(self.tab_5)
        self.label_112.setGeometry(QtCore.QRect(160, 50, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_112.setFont(font)
        self.label_112.setAlignment(QtCore.Qt.AlignCenter)
        self.label_112.setWordWrap(False)
        self.label_112.setObjectName("label_112")
        self.label_177 = QtWidgets.QLabel(self.tab_5)
        self.label_177.setGeometry(QtCore.QRect(190, 80, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_177.setFont(font)
        self.label_177.setObjectName("label_177")
        self.delayTimeTimeChange = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.delayTimeTimeChange.setGeometry(QtCore.QRect(240, 80, 51, 22))
        self.delayTimeTimeChange.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.delayTimeTimeChange.setDecimals(0)
        self.delayTimeTimeChange.setMinimum(1.0)
        self.delayTimeTimeChange.setMaximum(300.0)
        self.delayTimeTimeChange.setSingleStep(1.0)
        self.delayTimeTimeChange.setProperty("value", 30.0)
        self.delayTimeTimeChange.setObjectName("delayTimeTimeChange")
        self.label_115 = QtWidgets.QLabel(self.tab_5)
        self.label_115.setGeometry(QtCore.QRect(290, 80, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_115.setFont(font)
        self.label_115.setAlignment(QtCore.Qt.AlignCenter)
        self.label_115.setWordWrap(False)
        self.label_115.setObjectName("label_115")
        self.label_118 = QtWidgets.QLabel(self.tab_5)
        self.label_118.setGeometry(QtCore.QRect(10, 160, 191, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_118.setFont(font)
        self.label_118.setObjectName("label_118")
        self.line_37 = QtWidgets.QFrame(self.tab_5)
        self.line_37.setGeometry(QtCore.QRect(10, 170, 291, 21))
        self.line_37.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_37.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_37.setObjectName("line_37")
        self.btn_runHystereseModel = QtWidgets.QPushButton(self.tab_5)
        self.btn_runHystereseModel.setGeometry(QtCore.QRect(10, 280, 291, 31))
        self.btn_runHystereseModel.setObjectName("btn_runHystereseModel")
        self.le_analyseFileName = QtWidgets.QLineEdit(self.tab_5)
        self.le_analyseFileName.setGeometry(QtCore.QRect(430, 50, 311, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_analyseFileName.setFont(font)
        self.le_analyseFileName.setMouseTracking(False)
        self.le_analyseFileName.setAcceptDrops(False)
        self.le_analyseFileName.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_analyseFileName.setReadOnly(False)
        self.le_analyseFileName.setObjectName("le_analyseFileName")
        self.line_29 = QtWidgets.QFrame(self.tab_5)
        self.line_29.setGeometry(QtCore.QRect(430, 30, 311, 21))
        self.line_29.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_29.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_29.setObjectName("line_29")
        self.btn_openAnalyseWindow = QtWidgets.QPushButton(self.tab_5)
        self.btn_openAnalyseWindow.setGeometry(QtCore.QRect(430, 130, 281, 31))
        self.btn_openAnalyseWindow.setObjectName("btn_openAnalyseWindow")
        self.btn_selectAnalyseFileName = QtWidgets.QPushButton(self.tab_5)
        self.btn_selectAnalyseFileName.setGeometry(QtCore.QRect(430, 80, 121, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_selectAnalyseFileName.setFont(font)
        self.btn_selectAnalyseFileName.setObjectName("btn_selectAnalyseFileName")
        self.label_99 = QtWidgets.QLabel(self.tab_5)
        self.label_99.setGeometry(QtCore.QRect(430, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_99.setFont(font)
        self.label_99.setObjectName("label_99")
        self.label_182 = QtWidgets.QLabel(self.tab_5)
        self.label_182.setGeometry(QtCore.QRect(190, 220, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_182.setFont(font)
        self.label_182.setObjectName("label_182")
        self.numberRunsHysterese = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.numberRunsHysterese.setGeometry(QtCore.QRect(110, 250, 51, 22))
        self.numberRunsHysterese.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numberRunsHysterese.setDecimals(0)
        self.numberRunsHysterese.setMinimum(1.0)
        self.numberRunsHysterese.setMaximum(50.0)
        self.numberRunsHysterese.setSingleStep(1.0)
        self.numberRunsHysterese.setProperty("value", 5.0)
        self.numberRunsHysterese.setObjectName("numberRunsHysterese")
        self.label_183 = QtWidgets.QLabel(self.tab_5)
        self.label_183.setGeometry(QtCore.QRect(10, 250, 91, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_183.setFont(font)
        self.label_183.setObjectName("label_183")
        self.label_184 = QtWidgets.QLabel(self.tab_5)
        self.label_184.setGeometry(QtCore.QRect(190, 250, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_184.setFont(font)
        self.label_184.setObjectName("label_184")
        self.delayTimeHysterese = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.delayTimeHysterese.setGeometry(QtCore.QRect(240, 250, 51, 22))
        self.delayTimeHysterese.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.delayTimeHysterese.setDecimals(0)
        self.delayTimeHysterese.setMinimum(1.0)
        self.delayTimeHysterese.setMaximum(300.0)
        self.delayTimeHysterese.setSingleStep(1.0)
        self.delayTimeHysterese.setProperty("value", 30.0)
        self.delayTimeHysterese.setObjectName("delayTimeHysterese")
        self.azimuthHysterese2 = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.azimuthHysterese2.setGeometry(QtCore.QRect(240, 220, 51, 22))
        self.azimuthHysterese2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.azimuthHysterese2.setDecimals(0)
        self.azimuthHysterese2.setMaximum(359.0)
        self.azimuthHysterese2.setSingleStep(1.0)
        self.azimuthHysterese2.setProperty("value", 0.0)
        self.azimuthHysterese2.setObjectName("azimuthHysterese2")
        self.label_117 = QtWidgets.QLabel(self.tab_5)
        self.label_117.setGeometry(QtCore.QRect(290, 250, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_117.setFont(font)
        self.label_117.setAlignment(QtCore.Qt.AlignCenter)
        self.label_117.setWordWrap(False)
        self.label_117.setObjectName("label_117")
        self.label_114 = QtWidgets.QLabel(self.tab_5)
        self.label_114.setGeometry(QtCore.QRect(160, 220, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_114.setFont(font)
        self.label_114.setAlignment(QtCore.Qt.AlignCenter)
        self.label_114.setWordWrap(False)
        self.label_114.setObjectName("label_114")
        self.altitudeHysterese2 = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.altitudeHysterese2.setGeometry(QtCore.QRect(110, 220, 51, 22))
        self.altitudeHysterese2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.altitudeHysterese2.setDecimals(0)
        self.altitudeHysterese2.setMinimum(0.0)
        self.altitudeHysterese2.setMaximum(90.0)
        self.altitudeHysterese2.setSingleStep(1.0)
        self.altitudeHysterese2.setProperty("value", 45.0)
        self.altitudeHysterese2.setObjectName("altitudeHysterese2")
        self.label_119 = QtWidgets.QLabel(self.tab_5)
        self.label_119.setGeometry(QtCore.QRect(290, 220, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_119.setFont(font)
        self.label_119.setAlignment(QtCore.Qt.AlignCenter)
        self.label_119.setWordWrap(False)
        self.label_119.setObjectName("label_119")
        self.label_185 = QtWidgets.QLabel(self.tab_5)
        self.label_185.setGeometry(QtCore.QRect(10, 190, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_185.setFont(font)
        self.label_185.setObjectName("label_185")
        self.label_120 = QtWidgets.QLabel(self.tab_5)
        self.label_120.setGeometry(QtCore.QRect(160, 190, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_120.setFont(font)
        self.label_120.setAlignment(QtCore.Qt.AlignCenter)
        self.label_120.setWordWrap(False)
        self.label_120.setObjectName("label_120")
        self.label_121 = QtWidgets.QLabel(self.tab_5)
        self.label_121.setGeometry(QtCore.QRect(290, 190, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_121.setFont(font)
        self.label_121.setAlignment(QtCore.Qt.AlignCenter)
        self.label_121.setWordWrap(False)
        self.label_121.setObjectName("label_121")
        self.azimuthHysterese1 = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.azimuthHysterese1.setGeometry(QtCore.QRect(240, 190, 51, 22))
        self.azimuthHysterese1.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.azimuthHysterese1.setDecimals(0)
        self.azimuthHysterese1.setMaximum(359.0)
        self.azimuthHysterese1.setSingleStep(1.0)
        self.azimuthHysterese1.setProperty("value", 0.0)
        self.azimuthHysterese1.setObjectName("azimuthHysterese1")
        self.altitudeHysterese1 = QtWidgets.QDoubleSpinBox(self.tab_5)
        self.altitudeHysterese1.setGeometry(QtCore.QRect(110, 190, 51, 22))
        self.altitudeHysterese1.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.altitudeHysterese1.setDecimals(0)
        self.altitudeHysterese1.setMinimum(0.0)
        self.altitudeHysterese1.setMaximum(90.0)
        self.altitudeHysterese1.setSingleStep(1.0)
        self.altitudeHysterese1.setProperty("value", 45.0)
        self.altitudeHysterese1.setObjectName("altitudeHysterese1")
        self.label_186 = QtWidgets.QLabel(self.tab_5)
        self.label_186.setGeometry(QtCore.QRect(190, 190, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_186.setFont(font)
        self.label_186.setObjectName("label_186")
        self.line_43 = QtWidgets.QFrame(self.tab_5)
        self.line_43.setGeometry(QtCore.QRect(10, 170, 291, 21))
        self.line_43.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_43.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_43.setObjectName("line_43")
        self.label_187 = QtWidgets.QLabel(self.tab_5)
        self.label_187.setGeometry(QtCore.QRect(10, 220, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_187.setFont(font)
        self.label_187.setObjectName("label_187")
        self.btn_runBatchModel = QtWidgets.QPushButton(self.tab_5)
        self.btn_runBatchModel.setGeometry(QtCore.QRect(430, 200, 281, 31))
        self.btn_runBatchModel.setObjectName("btn_runBatchModel")
        self.tabWidget.addTab(self.tab_5, "")
        self.tab_8 = QtWidgets.QWidget()
        self.tab_8.setObjectName("tab_8")
        self.le_alignNumberStars = QtWidgets.QLineEdit(self.tab_8)
        self.le_alignNumberStars.setGeometry(QtCore.QRect(50, 90, 31, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_alignNumberStars.setFont(font)
        self.le_alignNumberStars.setMouseTracking(False)
        self.le_alignNumberStars.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_alignNumberStars.setAcceptDrops(False)
        self.le_alignNumberStars.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_alignNumberStars.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_alignNumberStars.setReadOnly(True)
        self.le_alignNumberStars.setObjectName("le_alignNumberStars")
        self.label = QtWidgets.QLabel(self.tab_8)
        self.label.setGeometry(QtCore.QRect(10, 90, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.le_alignError = QtWidgets.QLineEdit(self.tab_8)
        self.le_alignError.setGeometry(QtCore.QRect(130, 90, 51, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_alignError.setFont(font)
        self.le_alignError.setMouseTracking(False)
        self.le_alignError.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_alignError.setAcceptDrops(False)
        self.le_alignError.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_alignError.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_alignError.setReadOnly(True)
        self.le_alignError.setObjectName("le_alignError")
        self.alignErrorStars = QtWidgets.QTextBrowser(self.tab_8)
        self.alignErrorStars.setGeometry(QtCore.QRect(10, 120, 431, 351))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(8)
        self.alignErrorStars.setFont(font)
        self.alignErrorStars.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.alignErrorStars.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.alignErrorStars.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustToContents)
        self.alignErrorStars.setObjectName("alignErrorStars")
        self.label_14 = QtWidgets.QLabel(self.tab_8)
        self.label_14.setGeometry(QtCore.QRect(100, 90, 31, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_14.setFont(font)
        self.label_14.setObjectName("label_14")
        self.btn_showActualModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_showActualModel.setGeometry(QtCore.QRect(10, 50, 131, 31))
        self.btn_showActualModel.setObjectName("btn_showActualModel")
        self.label_37 = QtWidgets.QLabel(self.tab_8)
        self.label_37.setGeometry(QtCore.QRect(200, 90, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_37.setFont(font)
        self.label_37.setObjectName("label_37")
        self.btn_runTargetRMSAlignment = QtWidgets.QPushButton(self.tab_8)
        self.btn_runTargetRMSAlignment.setGeometry(QtCore.QRect(160, 50, 131, 31))
        self.btn_runTargetRMSAlignment.setObjectName("btn_runTargetRMSAlignment")
        self.targetRMS = QtWidgets.QDoubleSpinBox(self.tab_8)
        self.targetRMS.setGeometry(QtCore.QRect(240, 90, 51, 22))
        self.targetRMS.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.targetRMS.setDecimals(1)
        self.targetRMS.setMaximum(30.0)
        self.targetRMS.setSingleStep(0.1)
        self.targetRMS.setObjectName("targetRMS")
        self.btn_saveBackupModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_saveBackupModel.setGeometry(QtCore.QRect(480, 50, 81, 31))
        self.btn_saveBackupModel.setObjectName("btn_saveBackupModel")
        self.btn_loadBackupModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_loadBackupModel.setGeometry(QtCore.QRect(670, 50, 81, 31))
        self.btn_loadBackupModel.setObjectName("btn_loadBackupModel")
        self.line_18 = QtWidgets.QFrame(self.tab_8)
        self.line_18.setGeometry(QtCore.QRect(480, 30, 271, 21))
        self.line_18.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_18.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_18.setObjectName("line_18")
        self.btn_loadSimpleModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_loadSimpleModel.setGeometry(QtCore.QRect(670, 170, 81, 31))
        self.btn_loadSimpleModel.setObjectName("btn_loadSimpleModel")
        self.btn_saveSimpleModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_saveSimpleModel.setGeometry(QtCore.QRect(480, 170, 81, 31))
        self.btn_saveSimpleModel.setObjectName("btn_saveSimpleModel")
        self.btn_deleteWorstPoint = QtWidgets.QPushButton(self.tab_8)
        self.btn_deleteWorstPoint.setGeometry(QtCore.QRect(310, 50, 131, 31))
        self.btn_deleteWorstPoint.setObjectName("btn_deleteWorstPoint")
        self.line_44 = QtWidgets.QFrame(self.tab_8)
        self.line_44.setGeometry(QtCore.QRect(10, 30, 431, 21))
        self.line_44.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_44.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_44.setObjectName("line_44")
        self.label_124 = QtWidgets.QLabel(self.tab_8)
        self.label_124.setGeometry(QtCore.QRect(10, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_124.setFont(font)
        self.label_124.setObjectName("label_124")
        self.label_125 = QtWidgets.QLabel(self.tab_8)
        self.label_125.setGeometry(QtCore.QRect(480, 20, 241, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_125.setFont(font)
        self.label_125.setObjectName("label_125")
        self.btn_loadBaseModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_loadBaseModel.setGeometry(QtCore.QRect(670, 90, 81, 31))
        self.btn_loadBaseModel.setObjectName("btn_loadBaseModel")
        self.btn_saveBaseModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_saveBaseModel.setGeometry(QtCore.QRect(480, 90, 81, 31))
        self.btn_saveBaseModel.setObjectName("btn_saveBaseModel")
        self.label_126 = QtWidgets.QLabel(self.tab_8)
        self.label_126.setGeometry(QtCore.QRect(560, 50, 111, 31))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.label_126.setFont(font)
        self.label_126.setAlignment(QtCore.Qt.AlignCenter)
        self.label_126.setObjectName("label_126")
        self.label_127 = QtWidgets.QLabel(self.tab_8)
        self.label_127.setGeometry(QtCore.QRect(560, 90, 111, 31))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.label_127.setFont(font)
        self.label_127.setAlignment(QtCore.Qt.AlignCenter)
        self.label_127.setObjectName("label_127")
        self.label_128 = QtWidgets.QLabel(self.tab_8)
        self.label_128.setGeometry(QtCore.QRect(560, 170, 111, 31))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.label_128.setFont(font)
        self.label_128.setAlignment(QtCore.Qt.AlignCenter)
        self.label_128.setObjectName("label_128")
        self.btn_saveDSO1Model = QtWidgets.QPushButton(self.tab_8)
        self.btn_saveDSO1Model.setGeometry(QtCore.QRect(480, 210, 81, 31))
        self.btn_saveDSO1Model.setObjectName("btn_saveDSO1Model")
        self.btn_loadDSO1Model = QtWidgets.QPushButton(self.tab_8)
        self.btn_loadDSO1Model.setGeometry(QtCore.QRect(670, 210, 81, 31))
        self.btn_loadDSO1Model.setObjectName("btn_loadDSO1Model")
        self.btn_saveDSO2Model = QtWidgets.QPushButton(self.tab_8)
        self.btn_saveDSO2Model.setGeometry(QtCore.QRect(480, 250, 81, 31))
        self.btn_saveDSO2Model.setObjectName("btn_saveDSO2Model")
        self.btn_loadDSO2Model = QtWidgets.QPushButton(self.tab_8)
        self.btn_loadDSO2Model.setGeometry(QtCore.QRect(670, 250, 81, 31))
        self.btn_loadDSO2Model.setObjectName("btn_loadDSO2Model")
        self.label_129 = QtWidgets.QLabel(self.tab_8)
        self.label_129.setGeometry(QtCore.QRect(560, 210, 111, 31))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.label_129.setFont(font)
        self.label_129.setAlignment(QtCore.Qt.AlignCenter)
        self.label_129.setObjectName("label_129")
        self.label_130 = QtWidgets.QLabel(self.tab_8)
        self.label_130.setGeometry(QtCore.QRect(560, 250, 111, 31))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.label_130.setFont(font)
        self.label_130.setAlignment(QtCore.Qt.AlignCenter)
        self.label_130.setObjectName("label_130")
        self.btn_saveRefinementModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_saveRefinementModel.setGeometry(QtCore.QRect(480, 130, 81, 31))
        self.btn_saveRefinementModel.setObjectName("btn_saveRefinementModel")
        self.label_133 = QtWidgets.QLabel(self.tab_8)
        self.label_133.setGeometry(QtCore.QRect(560, 130, 111, 31))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.label_133.setFont(font)
        self.label_133.setAlignment(QtCore.Qt.AlignCenter)
        self.label_133.setObjectName("label_133")
        self.btn_loadRefinementModel = QtWidgets.QPushButton(self.tab_8)
        self.btn_loadRefinementModel.setGeometry(QtCore.QRect(670, 130, 81, 31))
        self.btn_loadRefinementModel.setObjectName("btn_loadRefinementModel")
        self.line_46 = QtWidgets.QFrame(self.tab_8)
        self.line_46.setGeometry(QtCore.QRect(450, 20, 21, 451))
        self.line_46.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_46.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_46.setObjectName("line_46")
        self.model = QtWidgets.QWidget(self.tab_8)
        self.model.setEnabled(True)
        self.model.setGeometry(QtCore.QRect(10, 120, 431, 351))
        self.model.setAutoFillBackground(True)
        self.model.setObjectName("model")
        self.checkPolarPlot = QtWidgets.QCheckBox(self.tab_8)
        self.checkPolarPlot.setGeometry(QtCore.QRect(320, 90, 101, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkPolarPlot.setFont(font)
        self.checkPolarPlot.setObjectName("checkPolarPlot")
        self.le_alignNumberStars.raise_()
        self.label.raise_()
        self.le_alignError.raise_()
        self.label_14.raise_()
        self.btn_showActualModel.raise_()
        self.label_37.raise_()
        self.btn_runTargetRMSAlignment.raise_()
        self.targetRMS.raise_()
        self.btn_saveBackupModel.raise_()
        self.btn_loadBackupModel.raise_()
        self.line_18.raise_()
        self.btn_loadSimpleModel.raise_()
        self.btn_saveSimpleModel.raise_()
        self.btn_deleteWorstPoint.raise_()
        self.line_44.raise_()
        self.label_124.raise_()
        self.label_125.raise_()
        self.btn_loadBaseModel.raise_()
        self.btn_saveBaseModel.raise_()
        self.label_126.raise_()
        self.label_127.raise_()
        self.label_128.raise_()
        self.btn_saveDSO1Model.raise_()
        self.btn_loadDSO1Model.raise_()
        self.btn_saveDSO2Model.raise_()
        self.btn_loadDSO2Model.raise_()
        self.label_129.raise_()
        self.label_130.raise_()
        self.btn_saveRefinementModel.raise_()
        self.label_133.raise_()
        self.btn_loadRefinementModel.raise_()
        self.line_46.raise_()
        self.model.raise_()
        self.alignErrorStars.raise_()
        self.checkPolarPlot.raise_()
        self.tabWidget.addTab(self.tab_8, "")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.le_siteElevation = QtWidgets.QLineEdit(self.tab_4)
        self.le_siteElevation.setGeometry(QtCore.QRect(140, 110, 101, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_siteElevation.setFont(font)
        self.le_siteElevation.setMouseTracking(False)
        self.le_siteElevation.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_siteElevation.setAcceptDrops(False)
        self.le_siteElevation.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_siteElevation.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_siteElevation.setReadOnly(True)
        self.le_siteElevation.setObjectName("le_siteElevation")
        self.label_5 = QtWidgets.QLabel(self.tab_4)
        self.label_5.setGeometry(QtCore.QRect(10, 50, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_5.setFont(font)
        self.label_5.setObjectName("label_5")
        self.le_siteLongitude = QtWidgets.QLineEdit(self.tab_4)
        self.le_siteLongitude.setGeometry(QtCore.QRect(120, 50, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_siteLongitude.setFont(font)
        self.le_siteLongitude.setMouseTracking(False)
        self.le_siteLongitude.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_siteLongitude.setAcceptDrops(False)
        self.le_siteLongitude.setToolTip("")
        self.le_siteLongitude.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_siteLongitude.setMaxLength(32634)
        self.le_siteLongitude.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_siteLongitude.setReadOnly(True)
        self.le_siteLongitude.setCursorMoveStyle(QtCore.Qt.VisualMoveStyle)
        self.le_siteLongitude.setObjectName("le_siteLongitude")
        self.label_6 = QtWidgets.QLabel(self.tab_4)
        self.label_6.setGeometry(QtCore.QRect(10, 80, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_6.setFont(font)
        self.label_6.setObjectName("label_6")
        self.le_localTime = QtWidgets.QLineEdit(self.tab_4)
        self.le_localTime.setGeometry(QtCore.QRect(140, 140, 101, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_localTime.setFont(font)
        self.le_localTime.setMouseTracking(False)
        self.le_localTime.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_localTime.setAcceptDrops(False)
        self.le_localTime.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_localTime.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_localTime.setReadOnly(True)
        self.le_localTime.setObjectName("le_localTime")
        self.label_7 = QtWidgets.QLabel(self.tab_4)
        self.label_7.setGeometry(QtCore.QRect(10, 140, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_7.setFont(font)
        self.label_7.setObjectName("label_7")
        self.le_siteLatitude = QtWidgets.QLineEdit(self.tab_4)
        self.le_siteLatitude.setGeometry(QtCore.QRect(120, 80, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_siteLatitude.setFont(font)
        self.le_siteLatitude.setMouseTracking(False)
        self.le_siteLatitude.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_siteLatitude.setAcceptDrops(False)
        self.le_siteLatitude.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_siteLatitude.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_siteLatitude.setReadOnly(True)
        self.le_siteLatitude.setObjectName("le_siteLatitude")
        self.label_12 = QtWidgets.QLabel(self.tab_4)
        self.label_12.setGeometry(QtCore.QRect(10, 110, 111, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_12.setFont(font)
        self.label_12.setObjectName("label_12")
        self.le_horizonLimitHigh = QtWidgets.QLineEdit(self.tab_4)
        self.le_horizonLimitHigh.setGeometry(QtCore.QRect(140, 250, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_horizonLimitHigh.setFont(font)
        self.le_horizonLimitHigh.setMouseTracking(False)
        self.le_horizonLimitHigh.setAcceptDrops(False)
        self.le_horizonLimitHigh.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_horizonLimitHigh.setCursorPosition(3)
        self.le_horizonLimitHigh.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_horizonLimitHigh.setReadOnly(False)
        self.le_horizonLimitHigh.setObjectName("le_horizonLimitHigh")
        self.label_4 = QtWidgets.QLabel(self.tab_4)
        self.label_4.setGeometry(QtCore.QRect(10, 220, 91, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.le_horizonLimitLow = QtWidgets.QLineEdit(self.tab_4)
        self.le_horizonLimitLow.setGeometry(QtCore.QRect(140, 220, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_horizonLimitLow.setFont(font)
        self.le_horizonLimitLow.setMouseTracking(False)
        self.le_horizonLimitLow.setAcceptDrops(False)
        self.le_horizonLimitLow.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_horizonLimitLow.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_horizonLimitLow.setReadOnly(False)
        self.le_horizonLimitLow.setClearButtonEnabled(False)
        self.le_horizonLimitLow.setObjectName("le_horizonLimitLow")
        self.label_20 = QtWidgets.QLabel(self.tab_4)
        self.label_20.setGeometry(QtCore.QRect(10, 250, 91, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_20.setFont(font)
        self.label_20.setObjectName("label_20")
        self.btn_setHorizonLimitLow = QtWidgets.QPushButton(self.tab_4)
        self.btn_setHorizonLimitLow.setGeometry(QtCore.QRect(220, 220, 31, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setHorizonLimitLow.setFont(font)
        self.btn_setHorizonLimitLow.setObjectName("btn_setHorizonLimitLow")
        self.btn_setHorizonLimitHigh = QtWidgets.QPushButton(self.tab_4)
        self.btn_setHorizonLimitHigh.setGeometry(QtCore.QRect(220, 250, 31, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setHorizonLimitHigh.setFont(font)
        self.btn_setHorizonLimitHigh.setObjectName("btn_setHorizonLimitHigh")
        self.label_58 = QtWidgets.QLabel(self.tab_4)
        self.label_58.setGeometry(QtCore.QRect(10, 20, 181, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_58.setFont(font)
        self.label_58.setObjectName("label_58")
        self.line_8 = QtWidgets.QFrame(self.tab_4)
        self.line_8.setGeometry(QtCore.QRect(10, 30, 241, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_8.setFont(font)
        self.line_8.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_8.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_8.setObjectName("line_8")
        self.label_59 = QtWidgets.QLabel(self.tab_4)
        self.label_59.setGeometry(QtCore.QRect(10, 190, 181, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_59.setFont(font)
        self.label_59.setObjectName("label_59")
        self.line_9 = QtWidgets.QFrame(self.tab_4)
        self.line_9.setGeometry(QtCore.QRect(10, 200, 241, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_9.setFont(font)
        self.line_9.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_9.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_9.setObjectName("line_9")
        self.label_16 = QtWidgets.QLabel(self.tab_4)
        self.label_16.setGeometry(QtCore.QRect(10, 330, 61, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_16.setFont(font)
        self.label_16.setObjectName("label_16")
        self.le_telescopeTempDECMotor = QtWidgets.QLineEdit(self.tab_4)
        self.le_telescopeTempDECMotor.setGeometry(QtCore.QRect(80, 330, 61, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_telescopeTempDECMotor.setFont(font)
        self.le_telescopeTempDECMotor.setMouseTracking(False)
        self.le_telescopeTempDECMotor.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_telescopeTempDECMotor.setAcceptDrops(False)
        self.le_telescopeTempDECMotor.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_telescopeTempDECMotor.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_telescopeTempDECMotor.setReadOnly(True)
        self.le_telescopeTempDECMotor.setObjectName("le_telescopeTempDECMotor")
        self.label_55 = QtWidgets.QLabel(self.tab_4)
        self.label_55.setGeometry(QtCore.QRect(10, 300, 191, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_55.setFont(font)
        self.label_55.setObjectName("label_55")
        self.line_5 = QtWidgets.QFrame(self.tab_4)
        self.line_5.setGeometry(QtCore.QRect(10, 310, 241, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_5.setFont(font)
        self.line_5.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_5.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_5.setObjectName("line_5")
        self.label_42 = QtWidgets.QLabel(self.tab_4)
        self.label_42.setGeometry(QtCore.QRect(190, 220, 16, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_42.setFont(font)
        self.label_42.setObjectName("label_42")
        self.label_60 = QtWidgets.QLabel(self.tab_4)
        self.label_60.setGeometry(QtCore.QRect(190, 250, 16, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_60.setFont(font)
        self.label_60.setObjectName("label_60")
        self.label_64 = QtWidgets.QLabel(self.tab_4)
        self.label_64.setGeometry(QtCore.QRect(150, 330, 16, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_64.setFont(font)
        self.label_64.setObjectName("label_64")
        self.line_7 = QtWidgets.QFrame(self.tab_4)
        self.line_7.setGeometry(QtCore.QRect(330, 30, 411, 21))
        self.line_7.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_7.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_7.setObjectName("line_7")
        self.label_76 = QtWidgets.QLabel(self.tab_4)
        self.label_76.setGeometry(QtCore.QRect(590, 70, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_76.setFont(font)
        self.label_76.setAlignment(QtCore.Qt.AlignCenter)
        self.label_76.setWordWrap(False)
        self.label_76.setObjectName("label_76")
        self.le_windSpeedWeather = QtWidgets.QLineEdit(self.tab_4)
        self.le_windSpeedWeather.setGeometry(QtCore.QRect(400, 250, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_windSpeedWeather.setFont(font)
        self.le_windSpeedWeather.setMouseTracking(False)
        self.le_windSpeedWeather.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_windSpeedWeather.setAcceptDrops(False)
        self.le_windSpeedWeather.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_windSpeedWeather.setMaxLength(8)
        self.le_windSpeedWeather.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_windSpeedWeather.setReadOnly(True)
        self.le_windSpeedWeather.setObjectName("le_windSpeedWeather")
        self.label_32 = QtWidgets.QLabel(self.tab_4)
        self.label_32.setGeometry(QtCore.QRect(330, 250, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_32.setFont(font)
        self.label_32.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_32.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_32.setObjectName("label_32")
        self.label_73 = QtWidgets.QLabel(self.tab_4)
        self.label_73.setGeometry(QtCore.QRect(470, 100, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_73.setFont(font)
        self.label_73.setAlignment(QtCore.Qt.AlignCenter)
        self.label_73.setWordWrap(False)
        self.label_73.setObjectName("label_73")
        self.le_temperatureStick = QtWidgets.QLineEdit(self.tab_4)
        self.le_temperatureStick.setGeometry(QtCore.QRect(520, 70, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_temperatureStick.setFont(font)
        self.le_temperatureStick.setMouseTracking(False)
        self.le_temperatureStick.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_temperatureStick.setAcceptDrops(False)
        self.le_temperatureStick.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_temperatureStick.setMaxLength(8)
        self.le_temperatureStick.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_temperatureStick.setReadOnly(True)
        self.le_temperatureStick.setObjectName("le_temperatureStick")
        self.le_temperatureWeather = QtWidgets.QLineEdit(self.tab_4)
        self.le_temperatureWeather.setGeometry(QtCore.QRect(400, 70, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_temperatureWeather.setFont(font)
        self.le_temperatureWeather.setMouseTracking(False)
        self.le_temperatureWeather.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_temperatureWeather.setAcceptDrops(False)
        self.le_temperatureWeather.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_temperatureWeather.setMaxLength(8)
        self.le_temperatureWeather.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_temperatureWeather.setReadOnly(True)
        self.le_temperatureWeather.setObjectName("le_temperatureWeather")
        self.label_25 = QtWidgets.QLabel(self.tab_4)
        self.label_25.setGeometry(QtCore.QRect(330, 130, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_25.setFont(font)
        self.label_25.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_25.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_25.setObjectName("label_25")
        self.label_31 = QtWidgets.QLabel(self.tab_4)
        self.label_31.setGeometry(QtCore.QRect(330, 220, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_31.setFont(font)
        self.label_31.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_31.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_31.setObjectName("label_31")
        self.le_pressureStick = QtWidgets.QLineEdit(self.tab_4)
        self.le_pressureStick.setGeometry(QtCore.QRect(520, 100, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_pressureStick.setFont(font)
        self.le_pressureStick.setMouseTracking(False)
        self.le_pressureStick.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_pressureStick.setAcceptDrops(False)
        self.le_pressureStick.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_pressureStick.setMaxLength(8)
        self.le_pressureStick.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_pressureStick.setReadOnly(True)
        self.le_pressureStick.setObjectName("le_pressureStick")
        self.label_75 = QtWidgets.QLabel(self.tab_4)
        self.label_75.setGeometry(QtCore.QRect(590, 100, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_75.setFont(font)
        self.label_75.setAlignment(QtCore.Qt.AlignCenter)
        self.label_75.setWordWrap(False)
        self.label_75.setObjectName("label_75")
        self.label_70 = QtWidgets.QLabel(self.tab_4)
        self.label_70.setGeometry(QtCore.QRect(470, 70, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_70.setFont(font)
        self.label_70.setAlignment(QtCore.Qt.AlignCenter)
        self.label_70.setWordWrap(False)
        self.label_70.setObjectName("label_70")
        self.label_68 = QtWidgets.QLabel(self.tab_4)
        self.label_68.setGeometry(QtCore.QRect(470, 220, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_68.setFont(font)
        self.label_68.setAlignment(QtCore.Qt.AlignCenter)
        self.label_68.setWordWrap(False)
        self.label_68.setObjectName("label_68")
        self.label_26 = QtWidgets.QLabel(self.tab_4)
        self.label_26.setGeometry(QtCore.QRect(330, 160, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_26.setFont(font)
        self.label_26.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_26.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_26.setObjectName("label_26")
        self.le_refractionTemperature = QtWidgets.QLineEdit(self.tab_4)
        self.le_refractionTemperature.setGeometry(QtCore.QRect(640, 70, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_refractionTemperature.setFont(font)
        self.le_refractionTemperature.setMouseTracking(False)
        self.le_refractionTemperature.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_refractionTemperature.setAcceptDrops(False)
        self.le_refractionTemperature.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_refractionTemperature.setMaxLength(8)
        self.le_refractionTemperature.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_refractionTemperature.setReadOnly(True)
        self.le_refractionTemperature.setObjectName("le_refractionTemperature")
        self.le_humidityWeather = QtWidgets.QLineEdit(self.tab_4)
        self.le_humidityWeather.setGeometry(QtCore.QRect(400, 160, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_humidityWeather.setFont(font)
        self.le_humidityWeather.setMouseTracking(False)
        self.le_humidityWeather.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_humidityWeather.setAcceptDrops(False)
        self.le_humidityWeather.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_humidityWeather.setMaxLength(8)
        self.le_humidityWeather.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_humidityWeather.setReadOnly(True)
        self.le_humidityWeather.setObjectName("le_humidityWeather")
        self.le_cloudCoverWeather = QtWidgets.QLineEdit(self.tab_4)
        self.le_cloudCoverWeather.setGeometry(QtCore.QRect(400, 190, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_cloudCoverWeather.setFont(font)
        self.le_cloudCoverWeather.setMouseTracking(False)
        self.le_cloudCoverWeather.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_cloudCoverWeather.setAcceptDrops(False)
        self.le_cloudCoverWeather.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_cloudCoverWeather.setMaxLength(8)
        self.le_cloudCoverWeather.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_cloudCoverWeather.setReadOnly(True)
        self.le_cloudCoverWeather.setObjectName("le_cloudCoverWeather")
        self.label_67 = QtWidgets.QLabel(self.tab_4)
        self.label_67.setGeometry(QtCore.QRect(470, 250, 41, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_67.setFont(font)
        self.label_67.setAlignment(QtCore.Qt.AlignCenter)
        self.label_67.setWordWrap(False)
        self.label_67.setObjectName("label_67")
        self.btn_setRefractionParameters = QtWidgets.QPushButton(self.tab_4)
        self.btn_setRefractionParameters.setGeometry(QtCore.QRect(330, 410, 291, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setRefractionParameters.setFont(font)
        self.btn_setRefractionParameters.setFlat(False)
        self.btn_setRefractionParameters.setObjectName("btn_setRefractionParameters")
        self.le_dewPointWeather = QtWidgets.QLineEdit(self.tab_4)
        self.le_dewPointWeather.setGeometry(QtCore.QRect(400, 130, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_dewPointWeather.setFont(font)
        self.le_dewPointWeather.setMouseTracking(False)
        self.le_dewPointWeather.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_dewPointWeather.setAcceptDrops(False)
        self.le_dewPointWeather.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_dewPointWeather.setMaxLength(8)
        self.le_dewPointWeather.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_dewPointWeather.setReadOnly(True)
        self.le_dewPointWeather.setObjectName("le_dewPointWeather")
        self.label_71 = QtWidgets.QLabel(self.tab_4)
        self.label_71.setGeometry(QtCore.QRect(470, 130, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_71.setFont(font)
        self.label_71.setAlignment(QtCore.Qt.AlignCenter)
        self.label_71.setWordWrap(False)
        self.label_71.setObjectName("label_71")
        self.le_windDirectionWeather = QtWidgets.QLineEdit(self.tab_4)
        self.le_windDirectionWeather.setGeometry(QtCore.QRect(400, 280, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_windDirectionWeather.setFont(font)
        self.le_windDirectionWeather.setMouseTracking(False)
        self.le_windDirectionWeather.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_windDirectionWeather.setAcceptDrops(False)
        self.le_windDirectionWeather.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_windDirectionWeather.setMaxLength(8)
        self.le_windDirectionWeather.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_windDirectionWeather.setReadOnly(True)
        self.le_windDirectionWeather.setObjectName("le_windDirectionWeather")
        self.label_33 = QtWidgets.QLabel(self.tab_4)
        self.label_33.setGeometry(QtCore.QRect(330, 280, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_33.setFont(font)
        self.label_33.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_33.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_33.setObjectName("label_33")
        self.label_77 = QtWidgets.QLabel(self.tab_4)
        self.label_77.setGeometry(QtCore.QRect(590, 160, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_77.setFont(font)
        self.label_77.setAlignment(QtCore.Qt.AlignCenter)
        self.label_77.setWordWrap(False)
        self.label_77.setObjectName("label_77")
        self.label_30 = QtWidgets.QLabel(self.tab_4)
        self.label_30.setGeometry(QtCore.QRect(330, 190, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_30.setFont(font)
        self.label_30.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_30.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_30.setObjectName("label_30")
        self.label_24 = QtWidgets.QLabel(self.tab_4)
        self.label_24.setGeometry(QtCore.QRect(330, 70, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_24.setFont(font)
        self.label_24.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_24.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_24.setObjectName("label_24")
        self.label_22 = QtWidgets.QLabel(self.tab_4)
        self.label_22.setGeometry(QtCore.QRect(330, 350, 181, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_22.setFont(font)
        self.label_22.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_22.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_22.setObjectName("label_22")
        self.label_74 = QtWidgets.QLabel(self.tab_4)
        self.label_74.setGeometry(QtCore.QRect(590, 130, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_74.setFont(font)
        self.label_74.setAlignment(QtCore.Qt.AlignCenter)
        self.label_74.setWordWrap(False)
        self.label_74.setObjectName("label_74")
        self.label_27 = QtWidgets.QLabel(self.tab_4)
        self.label_27.setGeometry(QtCore.QRect(330, 100, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_27.setFont(font)
        self.label_27.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_27.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_27.setObjectName("label_27")
        self.label_57 = QtWidgets.QLabel(self.tab_4)
        self.label_57.setGeometry(QtCore.QRect(330, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_57.setFont(font)
        self.label_57.setObjectName("label_57")
        self.line_10 = QtWidgets.QFrame(self.tab_4)
        self.line_10.setGeometry(QtCore.QRect(330, 330, 421, 21))
        self.line_10.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_10.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_10.setObjectName("line_10")
        self.le_dewPointStick = QtWidgets.QLineEdit(self.tab_4)
        self.le_dewPointStick.setGeometry(QtCore.QRect(520, 130, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_dewPointStick.setFont(font)
        self.le_dewPointStick.setMouseTracking(False)
        self.le_dewPointStick.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_dewPointStick.setAcceptDrops(False)
        self.le_dewPointStick.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_dewPointStick.setMaxLength(8)
        self.le_dewPointStick.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_dewPointStick.setReadOnly(True)
        self.le_dewPointStick.setObjectName("le_dewPointStick")
        self.le_refractionPressure = QtWidgets.QLineEdit(self.tab_4)
        self.le_refractionPressure.setGeometry(QtCore.QRect(640, 100, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_refractionPressure.setFont(font)
        self.le_refractionPressure.setMouseTracking(False)
        self.le_refractionPressure.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_refractionPressure.setAcceptDrops(False)
        self.le_refractionPressure.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_refractionPressure.setMaxLength(8)
        self.le_refractionPressure.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_refractionPressure.setReadOnly(True)
        self.le_refractionPressure.setObjectName("le_refractionPressure")
        self.le_rainRateWeather = QtWidgets.QLineEdit(self.tab_4)
        self.le_rainRateWeather.setGeometry(QtCore.QRect(400, 220, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_rainRateWeather.setFont(font)
        self.le_rainRateWeather.setMouseTracking(False)
        self.le_rainRateWeather.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_rainRateWeather.setAcceptDrops(False)
        self.le_rainRateWeather.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_rainRateWeather.setMaxLength(8)
        self.le_rainRateWeather.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_rainRateWeather.setReadOnly(True)
        self.le_rainRateWeather.setObjectName("le_rainRateWeather")
        self.label_66 = QtWidgets.QLabel(self.tab_4)
        self.label_66.setGeometry(QtCore.QRect(470, 280, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_66.setFont(font)
        self.label_66.setAlignment(QtCore.Qt.AlignCenter)
        self.label_66.setWordWrap(False)
        self.label_66.setObjectName("label_66")
        self.le_pressureWeather = QtWidgets.QLineEdit(self.tab_4)
        self.le_pressureWeather.setGeometry(QtCore.QRect(400, 100, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_pressureWeather.setFont(font)
        self.le_pressureWeather.setMouseTracking(False)
        self.le_pressureWeather.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_pressureWeather.setAcceptDrops(False)
        self.le_pressureWeather.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_pressureWeather.setMaxLength(8)
        self.le_pressureWeather.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_pressureWeather.setReadOnly(True)
        self.le_pressureWeather.setObjectName("le_pressureWeather")
        self.le_refractionStatus = QtWidgets.QLineEdit(self.tab_4)
        self.le_refractionStatus.setGeometry(QtCore.QRect(520, 350, 61, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_refractionStatus.setFont(font)
        self.le_refractionStatus.setMouseTracking(False)
        self.le_refractionStatus.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_refractionStatus.setAcceptDrops(False)
        self.le_refractionStatus.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_refractionStatus.setAlignment(QtCore.Qt.AlignCenter)
        self.le_refractionStatus.setReadOnly(True)
        self.le_refractionStatus.setObjectName("le_refractionStatus")
        self.le_humidityStick = QtWidgets.QLineEdit(self.tab_4)
        self.le_humidityStick.setGeometry(QtCore.QRect(520, 160, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_humidityStick.setFont(font)
        self.le_humidityStick.setMouseTracking(False)
        self.le_humidityStick.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_humidityStick.setAcceptDrops(False)
        self.le_humidityStick.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_humidityStick.setMaxLength(8)
        self.le_humidityStick.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_humidityStick.setReadOnly(True)
        self.le_humidityStick.setObjectName("le_humidityStick")
        self.label_28 = QtWidgets.QLabel(self.tab_4)
        self.label_28.setGeometry(QtCore.QRect(520, 40, 71, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_28.setFont(font)
        self.label_28.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_28.setAlignment(QtCore.Qt.AlignCenter)
        self.label_28.setObjectName("label_28")
        self.label_13 = QtWidgets.QLabel(self.tab_4)
        self.label_13.setGeometry(QtCore.QRect(630, 40, 111, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_13.setFont(font)
        self.label_13.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_13.setObjectName("label_13")
        self.label_29 = QtWidgets.QLabel(self.tab_4)
        self.label_29.setGeometry(QtCore.QRect(390, 40, 91, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_29.setFont(font)
        self.label_29.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_29.setAlignment(QtCore.Qt.AlignCenter)
        self.label_29.setObjectName("label_29")
        self.label_72 = QtWidgets.QLabel(self.tab_4)
        self.label_72.setGeometry(QtCore.QRect(470, 160, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_72.setFont(font)
        self.label_72.setAlignment(QtCore.Qt.AlignCenter)
        self.label_72.setWordWrap(False)
        self.label_72.setObjectName("label_72")
        self.label_69 = QtWidgets.QLabel(self.tab_4)
        self.label_69.setGeometry(QtCore.QRect(470, 190, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_69.setFont(font)
        self.label_69.setAlignment(QtCore.Qt.AlignCenter)
        self.label_69.setWordWrap(False)
        self.label_69.setObjectName("label_69")
        self.label_78 = QtWidgets.QLabel(self.tab_4)
        self.label_78.setGeometry(QtCore.QRect(710, 100, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_78.setFont(font)
        self.label_78.setAlignment(QtCore.Qt.AlignCenter)
        self.label_78.setWordWrap(False)
        self.label_78.setObjectName("label_78")
        self.label_82 = QtWidgets.QLabel(self.tab_4)
        self.label_82.setGeometry(QtCore.QRect(240, 110, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_82.setFont(font)
        self.label_82.setAlignment(QtCore.Qt.AlignCenter)
        self.label_82.setWordWrap(False)
        self.label_82.setObjectName("label_82")
        self.checkAutoRefraction = QtWidgets.QCheckBox(self.tab_4)
        self.checkAutoRefraction.setGeometry(QtCore.QRect(330, 380, 291, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkAutoRefraction.setFont(font)
        self.checkAutoRefraction.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.checkAutoRefraction.setChecked(True)
        self.checkAutoRefraction.setObjectName("checkAutoRefraction")
        self.label_86 = QtWidgets.QLabel(self.tab_4)
        self.label_86.setGeometry(QtCore.QRect(330, 320, 221, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_86.setFont(font)
        self.label_86.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_86.setObjectName("label_86")
        self.btn_setRefractionCorrection = QtWidgets.QPushButton(self.tab_4)
        self.btn_setRefractionCorrection.setGeometry(QtCore.QRect(590, 350, 31, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setRefractionCorrection.setFont(font)
        self.btn_setRefractionCorrection.setObjectName("btn_setRefractionCorrection")
        self.label_105 = QtWidgets.QLabel(self.tab_4)
        self.label_105.setGeometry(QtCore.QRect(240, 80, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_105.setFont(font)
        self.label_105.setAlignment(QtCore.Qt.AlignCenter)
        self.label_105.setWordWrap(False)
        self.label_105.setObjectName("label_105")
        self.label_106 = QtWidgets.QLabel(self.tab_4)
        self.label_106.setGeometry(QtCore.QRect(240, 50, 31, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_106.setFont(font)
        self.label_106.setAlignment(QtCore.Qt.AlignCenter)
        self.label_106.setWordWrap(False)
        self.label_106.setObjectName("label_106")
        self.label_79 = QtWidgets.QLabel(self.tab_4)
        self.label_79.setGeometry(QtCore.QRect(710, 70, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_79.setFont(font)
        self.label_79.setAlignment(QtCore.Qt.AlignCenter)
        self.label_79.setWordWrap(False)
        self.label_79.setObjectName("label_79")
        self.tabWidget.addTab(self.tab_4, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.tabWidget_2 = QtWidgets.QTabWidget(self.tab_3)
        self.tabWidget_2.setGeometry(QtCore.QRect(10, 10, 741, 461))
        self.tabWidget_2.setObjectName("tabWidget_2")
        self.tab_11 = QtWidgets.QWidget()
        self.tab_11.setObjectName("tab_11")
        self.label_41 = QtWidgets.QLabel(self.tab_11)
        self.label_41.setGeometry(QtCore.QRect(20, 220, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_41.setFont(font)
        self.label_41.setObjectName("label_41")
        self.label_122 = QtWidgets.QLabel(self.tab_11)
        self.label_122.setGeometry(QtCore.QRect(350, 170, 21, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_122.setFont(font)
        self.label_122.setAlignment(QtCore.Qt.AlignCenter)
        self.label_122.setWordWrap(False)
        self.label_122.setObjectName("label_122")
        self.btn_selectHorizonPointsFileName = QtWidgets.QPushButton(self.tab_11)
        self.btn_selectHorizonPointsFileName.setGeometry(QtCore.QRect(130, 110, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_selectHorizonPointsFileName.setFont(font)
        self.btn_selectHorizonPointsFileName.setObjectName("btn_selectHorizonPointsFileName")
        self.label_36 = QtWidgets.QLabel(self.tab_11)
        self.label_36.setGeometry(QtCore.QRect(20, 120, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_36.setFont(font)
        self.label_36.setObjectName("label_36")
        self.checkUseMinimumHorizonLine = QtWidgets.QCheckBox(self.tab_11)
        self.checkUseMinimumHorizonLine.setGeometry(QtCore.QRect(40, 170, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkUseMinimumHorizonLine.setFont(font)
        self.checkUseMinimumHorizonLine.setChecked(True)
        self.checkUseMinimumHorizonLine.setObjectName("checkUseMinimumHorizonLine")
        self.altitudeMinimumHorizon = QtWidgets.QDoubleSpinBox(self.tab_11)
        self.altitudeMinimumHorizon.setGeometry(QtCore.QRect(300, 170, 51, 22))
        self.altitudeMinimumHorizon.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.altitudeMinimumHorizon.setDecimals(0)
        self.altitudeMinimumHorizon.setMinimum(0.0)
        self.altitudeMinimumHorizon.setMaximum(90.0)
        self.altitudeMinimumHorizon.setSingleStep(1.0)
        self.altitudeMinimumHorizon.setProperty("value", 20.0)
        self.altitudeMinimumHorizon.setObjectName("altitudeMinimumHorizon")
        self.line_11 = QtWidgets.QFrame(self.tab_11)
        self.line_11.setGeometry(QtCore.QRect(20, 30, 351, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_11.setFont(font)
        self.line_11.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_11.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_11.setObjectName("line_11")
        self.le_imageDirectoryName = QtWidgets.QLineEdit(self.tab_11)
        self.le_imageDirectoryName.setGeometry(QtCore.QRect(20, 250, 351, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_imageDirectoryName.setFont(font)
        self.le_imageDirectoryName.setMouseTracking(False)
        self.le_imageDirectoryName.setAcceptDrops(False)
        self.le_imageDirectoryName.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_imageDirectoryName.setReadOnly(False)
        self.le_imageDirectoryName.setObjectName("le_imageDirectoryName")
        self.le_horizonPointsFileName = QtWidgets.QLineEdit(self.tab_11)
        self.le_horizonPointsFileName.setGeometry(QtCore.QRect(20, 140, 351, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_horizonPointsFileName.setFont(font)
        self.le_horizonPointsFileName.setMouseTracking(False)
        self.le_horizonPointsFileName.setAcceptDrops(False)
        self.le_horizonPointsFileName.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_horizonPointsFileName.setReadOnly(False)
        self.le_horizonPointsFileName.setObjectName("le_horizonPointsFileName")
        self.label_35 = QtWidgets.QLabel(self.tab_11)
        self.label_35.setGeometry(QtCore.QRect(20, 60, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_35.setFont(font)
        self.label_35.setObjectName("label_35")
        self.label_63 = QtWidgets.QLabel(self.tab_11)
        self.label_63.setGeometry(QtCore.QRect(20, 20, 201, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_63.setFont(font)
        self.label_63.setObjectName("label_63")
        self.btn_selectImageDirectoryName = QtWidgets.QPushButton(self.tab_11)
        self.btn_selectImageDirectoryName.setGeometry(QtCore.QRect(130, 220, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_selectImageDirectoryName.setFont(font)
        self.btn_selectImageDirectoryName.setObjectName("btn_selectImageDirectoryName")
        self.le_modelPointsFileName = QtWidgets.QLineEdit(self.tab_11)
        self.le_modelPointsFileName.setGeometry(QtCore.QRect(20, 80, 351, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_modelPointsFileName.setFont(font)
        self.le_modelPointsFileName.setMouseTracking(False)
        self.le_modelPointsFileName.setAcceptDrops(False)
        self.le_modelPointsFileName.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_modelPointsFileName.setReadOnly(False)
        self.le_modelPointsFileName.setObjectName("le_modelPointsFileName")
        self.checkKeepImages = QtWidgets.QCheckBox(self.tab_11)
        self.checkKeepImages.setGeometry(QtCore.QRect(40, 280, 231, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkKeepImages.setFont(font)
        self.checkKeepImages.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.checkKeepImages.setChecked(True)
        self.checkKeepImages.setObjectName("checkKeepImages")
        self.label_180 = QtWidgets.QLabel(self.tab_11)
        self.label_180.setGeometry(QtCore.QRect(250, 170, 51, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_180.setFont(font)
        self.label_180.setObjectName("label_180")
        self.btn_selectModelPointsFileName = QtWidgets.QPushButton(self.tab_11)
        self.btn_selectModelPointsFileName.setGeometry(QtCore.QRect(130, 50, 41, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_selectModelPointsFileName.setFont(font)
        self.btn_selectModelPointsFileName.setObjectName("btn_selectModelPointsFileName")
        self.label_38 = QtWidgets.QLabel(self.tab_11)
        self.label_38.setGeometry(QtCore.QRect(400, 170, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_38.setFont(font)
        self.label_38.setObjectName("label_38")
        self.label_169 = QtWidgets.QLabel(self.tab_11)
        self.label_169.setGeometry(QtCore.QRect(680, 230, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_169.setFont(font)
        self.label_169.setObjectName("label_169")
        self.label_173 = QtWidgets.QLabel(self.tab_11)
        self.label_173.setGeometry(QtCore.QRect(580, 260, 16, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_173.setFont(font)
        self.label_173.setObjectName("label_173")
        self.checkFastDownload = QtWidgets.QCheckBox(self.tab_11)
        self.checkFastDownload.setGeometry(QtCore.QRect(420, 110, 121, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkFastDownload.setFont(font)
        self.checkFastDownload.setChecked(True)
        self.checkFastDownload.setObjectName("checkFastDownload")
        self.label_168 = QtWidgets.QLabel(self.tab_11)
        self.label_168.setGeometry(QtCore.QRect(400, 230, 181, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_168.setFont(font)
        self.label_168.setObjectName("label_168")
        self.line_25 = QtWidgets.QFrame(self.tab_11)
        self.line_25.setGeometry(QtCore.QRect(400, 30, 311, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_25.setFont(font)
        self.line_25.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_25.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_25.setObjectName("line_25")
        self.settlingTime = QtWidgets.QDoubleSpinBox(self.tab_11)
        self.settlingTime.setGeometry(QtCore.QRect(620, 170, 51, 22))
        self.settlingTime.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.settlingTime.setDecimals(0)
        self.settlingTime.setMinimum(1.0)
        self.settlingTime.setMaximum(100.0)
        self.settlingTime.setSingleStep(1.0)
        self.settlingTime.setProperty("value", 1.0)
        self.settlingTime.setObjectName("settlingTime")
        self.isoSetting = QtWidgets.QDoubleSpinBox(self.tab_11)
        self.isoSetting.setGeometry(QtCore.QRect(600, 140, 71, 22))
        self.isoSetting.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.isoSetting.setDecimals(0)
        self.isoSetting.setMinimum(100.0)
        self.isoSetting.setMaximum(128000.0)
        self.isoSetting.setSingleStep(100.0)
        self.isoSetting.setProperty("value", 800.0)
        self.isoSetting.setObjectName("isoSetting")
        self.label_164 = QtWidgets.QLabel(self.tab_11)
        self.label_164.setGeometry(QtCore.QRect(580, 80, 16, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_164.setFont(font)
        self.label_164.setObjectName("label_164")
        self.scaleSubframe = QtWidgets.QDoubleSpinBox(self.tab_11)
        self.scaleSubframe.setGeometry(QtCore.QRect(520, 260, 51, 22))
        self.scaleSubframe.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.scaleSubframe.setDecimals(0)
        self.scaleSubframe.setMinimum(10.0)
        self.scaleSubframe.setMaximum(100.0)
        self.scaleSubframe.setSingleStep(10.0)
        self.scaleSubframe.setProperty("value", 100.0)
        self.scaleSubframe.setObjectName("scaleSubframe")
        self.label_172 = QtWidgets.QLabel(self.tab_11)
        self.label_172.setGeometry(QtCore.QRect(400, 140, 181, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_172.setFont(font)
        self.label_172.setObjectName("label_172")
        self.label_163 = QtWidgets.QLabel(self.tab_11)
        self.label_163.setGeometry(QtCore.QRect(400, 20, 201, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_163.setFont(font)
        self.label_163.setObjectName("label_163")
        self.label_166 = QtWidgets.QLabel(self.tab_11)
        self.label_166.setGeometry(QtCore.QRect(400, 200, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_166.setFont(font)
        self.label_166.setObjectName("label_166")
        self.cameraExposure = QtWidgets.QSpinBox(self.tab_11)
        self.cameraExposure.setGeometry(QtCore.QRect(520, 80, 51, 22))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.cameraExposure.setFont(font)
        self.cameraExposure.setContextMenuPolicy(QtCore.Qt.ActionsContextMenu)
        self.cameraExposure.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.cameraExposure.setMinimum(1)
        self.cameraExposure.setMaximum(10)
        self.cameraExposure.setProperty("value", 1)
        self.cameraExposure.setObjectName("cameraExposure")
        self.label_167 = QtWidgets.QLabel(self.tab_11)
        self.label_167.setGeometry(QtCore.QRect(680, 200, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_167.setFont(font)
        self.label_167.setObjectName("label_167")
        self.pixelSize = QtWidgets.QDoubleSpinBox(self.tab_11)
        self.pixelSize.setGeometry(QtCore.QRect(620, 200, 51, 22))
        self.pixelSize.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.pixelSize.setDecimals(1)
        self.pixelSize.setMaximum(10.0)
        self.pixelSize.setSingleStep(0.1)
        self.pixelSize.setProperty("value", 3.7)
        self.pixelSize.setObjectName("pixelSize")
        self.checkDoSubframe = QtWidgets.QCheckBox(self.tab_11)
        self.checkDoSubframe.setGeometry(QtCore.QRect(420, 290, 131, 20))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkDoSubframe.setFont(font)
        self.checkDoSubframe.setChecked(False)
        self.checkDoSubframe.setObjectName("checkDoSubframe")
        self.label_39 = QtWidgets.QLabel(self.tab_11)
        self.label_39.setGeometry(QtCore.QRect(400, 80, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_39.setFont(font)
        self.label_39.setObjectName("label_39")
        self.focalLength = QtWidgets.QDoubleSpinBox(self.tab_11)
        self.focalLength.setGeometry(QtCore.QRect(620, 230, 51, 22))
        self.focalLength.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.focalLength.setDecimals(0)
        self.focalLength.setMaximum(5000.0)
        self.focalLength.setSingleStep(1.0)
        self.focalLength.setProperty("value", 582.0)
        self.focalLength.setObjectName("focalLength")
        self.cameraBin = QtWidgets.QSpinBox(self.tab_11)
        self.cameraBin.setGeometry(QtCore.QRect(520, 50, 51, 22))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.cameraBin.setFont(font)
        self.cameraBin.setContextMenuPolicy(QtCore.Qt.ActionsContextMenu)
        self.cameraBin.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.cameraBin.setMinimum(1)
        self.cameraBin.setMaximum(3)
        self.cameraBin.setProperty("value", 1)
        self.cameraBin.setObjectName("cameraBin")
        self.label_102 = QtWidgets.QLabel(self.tab_11)
        self.label_102.setGeometry(QtCore.QRect(400, 260, 61, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_102.setFont(font)
        self.label_102.setObjectName("label_102")
        self.label_165 = QtWidgets.QLabel(self.tab_11)
        self.label_165.setGeometry(QtCore.QRect(680, 170, 16, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_165.setFont(font)
        self.label_165.setObjectName("label_165")
        self.label_40 = QtWidgets.QLabel(self.tab_11)
        self.label_40.setGeometry(QtCore.QRect(400, 50, 91, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_40.setFont(font)
        self.label_40.setObjectName("label_40")
        self.tabWidget_2.addTab(self.tab_11, "")
        self.tab_13 = QtWidgets.QWidget()
        self.tab_13.setObjectName("tab_13")
        self.btn_setupAscomCameraDriver = QtWidgets.QPushButton(self.tab_13)
        self.btn_setupAscomCameraDriver.setGeometry(QtCore.QRect(20, 140, 81, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setupAscomCameraDriver.setFont(font)
        self.btn_setupAscomCameraDriver.setObjectName("btn_setupAscomCameraDriver")
        self.line_20 = QtWidgets.QFrame(self.tab_13)
        self.line_20.setGeometry(QtCore.QRect(20, 120, 351, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_20.setFont(font)
        self.line_20.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_20.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_20.setObjectName("line_20")
        self.cameraPlateChooser = QtWidgets.QGroupBox(self.tab_13)
        self.cameraPlateChooser.setGeometry(QtCore.QRect(20, 30, 351, 61))
        self.cameraPlateChooser.setCheckable(False)
        self.cameraPlateChooser.setObjectName("cameraPlateChooser")
        self.rb_cameraSGPro = QtWidgets.QRadioButton(self.cameraPlateChooser)
        self.rb_cameraSGPro.setGeometry(QtCore.QRect(10, 20, 82, 31))
        font = QtGui.QFont()
        font.setPointSize(12)
        self.rb_cameraSGPro.setFont(font)
        self.rb_cameraSGPro.setChecked(True)
        self.rb_cameraSGPro.setObjectName("rb_cameraSGPro")
        self.rb_cameraTSX = QtWidgets.QRadioButton(self.cameraPlateChooser)
        self.rb_cameraTSX.setGeometry(QtCore.QRect(120, 20, 101, 31))
        font = QtGui.QFont()
        font.setPointSize(12)
        self.rb_cameraTSX.setFont(font)
        self.rb_cameraTSX.setObjectName("rb_cameraTSX")
        self.rb_cameraASCOM = QtWidgets.QRadioButton(self.cameraPlateChooser)
        self.rb_cameraASCOM.setGeometry(QtCore.QRect(230, 20, 101, 31))
        font = QtGui.QFont()
        font.setPointSize(12)
        self.rb_cameraASCOM.setFont(font)
        self.rb_cameraASCOM.setObjectName("rb_cameraASCOM")
        self.label_87 = QtWidgets.QLabel(self.tab_13)
        self.label_87.setGeometry(QtCore.QRect(20, 110, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_87.setFont(font)
        self.label_87.setObjectName("label_87")
        self.btn_setupPlateSolver = QtWidgets.QPushButton(self.tab_13)
        self.btn_setupPlateSolver.setGeometry(QtCore.QRect(110, 140, 81, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setupPlateSolver.setFont(font)
        self.btn_setupPlateSolver.setObjectName("btn_setupPlateSolver")
        self.tabWidget_2.addTab(self.tab_13, "")
        self.tab_12 = QtWidgets.QWidget()
        self.tab_12.setObjectName("tab_12")
        self.btn_setupStickDriver = QtWidgets.QPushButton(self.tab_12)
        self.btn_setupStickDriver.setGeometry(QtCore.QRect(200, 50, 81, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setupStickDriver.setFont(font)
        self.btn_setupStickDriver.setObjectName("btn_setupStickDriver")
        self.btn_setupWeatherDriver = QtWidgets.QPushButton(self.tab_12)
        self.btn_setupWeatherDriver.setGeometry(QtCore.QRect(290, 50, 81, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setupWeatherDriver.setFont(font)
        self.btn_setupWeatherDriver.setObjectName("btn_setupWeatherDriver")
        self.line_3 = QtWidgets.QFrame(self.tab_12)
        self.line_3.setGeometry(QtCore.QRect(20, 30, 351, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_3.setFont(font)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setObjectName("line_3")
        self.btn_setupMountDriver = QtWidgets.QPushButton(self.tab_12)
        self.btn_setupMountDriver.setGeometry(QtCore.QRect(20, 50, 81, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setupMountDriver.setFont(font)
        self.btn_setupMountDriver.setObjectName("btn_setupMountDriver")
        self.btn_setupDomeDriver = QtWidgets.QPushButton(self.tab_12)
        self.btn_setupDomeDriver.setGeometry(QtCore.QRect(110, 50, 81, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_setupDomeDriver.setFont(font)
        self.btn_setupDomeDriver.setObjectName("btn_setupDomeDriver")
        self.label_53 = QtWidgets.QLabel(self.tab_12)
        self.label_53.setGeometry(QtCore.QRect(20, 20, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_53.setFont(font)
        self.label_53.setObjectName("label_53")
        self.tabWidget_2.addTab(self.tab_12, "")
        self.tab_10 = QtWidgets.QWidget()
        self.tab_10.setObjectName("tab_10")
        self.le_altParkPos3 = QtWidgets.QLineEdit(self.tab_10)
        self.le_altParkPos3.setGeometry(QtCore.QRect(350, 110, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_altParkPos3.setFont(font)
        self.le_altParkPos3.setMouseTracking(False)
        self.le_altParkPos3.setAcceptDrops(False)
        self.le_altParkPos3.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_altParkPos3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_altParkPos3.setReadOnly(False)
        self.le_altParkPos3.setObjectName("le_altParkPos3")
        self.le_parkPos3Text = QtWidgets.QLineEdit(self.tab_10)
        self.le_parkPos3Text.setGeometry(QtCore.QRect(120, 110, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_parkPos3Text.setFont(font)
        self.le_parkPos3Text.setMouseTracking(False)
        self.le_parkPos3Text.setAcceptDrops(False)
        self.le_parkPos3Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_parkPos3Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.le_parkPos3Text.setReadOnly(False)
        self.le_parkPos3Text.setObjectName("le_parkPos3Text")
        self.le_parkPos1Text = QtWidgets.QLineEdit(self.tab_10)
        self.le_parkPos1Text.setGeometry(QtCore.QRect(120, 50, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_parkPos1Text.setFont(font)
        self.le_parkPos1Text.setMouseTracking(False)
        self.le_parkPos1Text.setAcceptDrops(False)
        self.le_parkPos1Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_parkPos1Text.setReadOnly(False)
        self.le_parkPos1Text.setObjectName("le_parkPos1Text")
        self.label_19 = QtWidgets.QLabel(self.tab_10)
        self.label_19.setGeometry(QtCore.QRect(260, 50, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_19.setFont(font)
        self.label_19.setObjectName("label_19")
        self.label_43 = QtWidgets.QLabel(self.tab_10)
        self.label_43.setGeometry(QtCore.QRect(260, 80, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_43.setFont(font)
        self.label_43.setObjectName("label_43")
        self.label_54 = QtWidgets.QLabel(self.tab_10)
        self.label_54.setGeometry(QtCore.QRect(20, 20, 191, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_54.setFont(font)
        self.label_54.setObjectName("label_54")
        self.le_azParkPos3 = QtWidgets.QLineEdit(self.tab_10)
        self.le_azParkPos3.setGeometry(QtCore.QRect(280, 110, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_azParkPos3.setFont(font)
        self.le_azParkPos3.setMouseTracking(False)
        self.le_azParkPos3.setAcceptDrops(False)
        self.le_azParkPos3.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_azParkPos3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_azParkPos3.setReadOnly(False)
        self.le_azParkPos3.setObjectName("le_azParkPos3")
        self.le_parkPos2Text = QtWidgets.QLineEdit(self.tab_10)
        self.le_parkPos2Text.setGeometry(QtCore.QRect(120, 80, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_parkPos2Text.setFont(font)
        self.le_parkPos2Text.setMouseTracking(False)
        self.le_parkPos2Text.setAcceptDrops(False)
        self.le_parkPos2Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_parkPos2Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.le_parkPos2Text.setReadOnly(False)
        self.le_parkPos2Text.setObjectName("le_parkPos2Text")
        self.le_azParkPos1 = QtWidgets.QLineEdit(self.tab_10)
        self.le_azParkPos1.setGeometry(QtCore.QRect(280, 50, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_azParkPos1.setFont(font)
        self.le_azParkPos1.setMouseTracking(False)
        self.le_azParkPos1.setAcceptDrops(False)
        self.le_azParkPos1.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_azParkPos1.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_azParkPos1.setReadOnly(False)
        self.le_azParkPos1.setObjectName("le_azParkPos1")
        self.label_45 = QtWidgets.QLabel(self.tab_10)
        self.label_45.setGeometry(QtCore.QRect(330, 80, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_45.setFont(font)
        self.label_45.setObjectName("label_45")
        self.le_altParkPos4 = QtWidgets.QLineEdit(self.tab_10)
        self.le_altParkPos4.setGeometry(QtCore.QRect(350, 140, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_altParkPos4.setFont(font)
        self.le_altParkPos4.setMouseTracking(False)
        self.le_altParkPos4.setAcceptDrops(False)
        self.le_altParkPos4.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_altParkPos4.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_altParkPos4.setReadOnly(False)
        self.le_altParkPos4.setObjectName("le_altParkPos4")
        self.le_altParkPos1 = QtWidgets.QLineEdit(self.tab_10)
        self.le_altParkPos1.setGeometry(QtCore.QRect(350, 50, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_altParkPos1.setFont(font)
        self.le_altParkPos1.setMouseTracking(False)
        self.le_altParkPos1.setAcceptDrops(False)
        self.le_altParkPos1.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_altParkPos1.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_altParkPos1.setReadOnly(False)
        self.le_altParkPos1.setObjectName("le_altParkPos1")
        self.label_2 = QtWidgets.QLabel(self.tab_10)
        self.label_2.setGeometry(QtCore.QRect(20, 50, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_2.setFont(font)
        self.label_2.setObjectName("label_2")
        self.le_altParkPos2 = QtWidgets.QLineEdit(self.tab_10)
        self.le_altParkPos2.setGeometry(QtCore.QRect(350, 80, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_altParkPos2.setFont(font)
        self.le_altParkPos2.setMouseTracking(False)
        self.le_altParkPos2.setAcceptDrops(False)
        self.le_altParkPos2.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_altParkPos2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_altParkPos2.setReadOnly(False)
        self.le_altParkPos2.setObjectName("le_altParkPos2")
        self.label_51 = QtWidgets.QLabel(self.tab_10)
        self.label_51.setGeometry(QtCore.QRect(330, 140, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_51.setFont(font)
        self.label_51.setObjectName("label_51")
        self.label_50 = QtWidgets.QLabel(self.tab_10)
        self.label_50.setGeometry(QtCore.QRect(20, 140, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_50.setFont(font)
        self.label_50.setObjectName("label_50")
        self.label_44 = QtWidgets.QLabel(self.tab_10)
        self.label_44.setGeometry(QtCore.QRect(20, 80, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_44.setFont(font)
        self.label_44.setObjectName("label_44")
        self.le_azParkPos2 = QtWidgets.QLineEdit(self.tab_10)
        self.le_azParkPos2.setGeometry(QtCore.QRect(280, 80, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_azParkPos2.setFont(font)
        self.le_azParkPos2.setMouseTracking(False)
        self.le_azParkPos2.setAcceptDrops(False)
        self.le_azParkPos2.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_azParkPos2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_azParkPos2.setReadOnly(False)
        self.le_azParkPos2.setObjectName("le_azParkPos2")
        self.label_49 = QtWidgets.QLabel(self.tab_10)
        self.label_49.setGeometry(QtCore.QRect(260, 140, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_49.setFont(font)
        self.label_49.setObjectName("label_49")
        self.label_3 = QtWidgets.QLabel(self.tab_10)
        self.label_3.setGeometry(QtCore.QRect(330, 50, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_3.setFont(font)
        self.label_3.setObjectName("label_3")
        self.line_4 = QtWidgets.QFrame(self.tab_10)
        self.line_4.setGeometry(QtCore.QRect(20, 30, 371, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_4.setFont(font)
        self.line_4.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_4.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_4.setObjectName("line_4")
        self.le_azParkPos4 = QtWidgets.QLineEdit(self.tab_10)
        self.le_azParkPos4.setGeometry(QtCore.QRect(280, 140, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_azParkPos4.setFont(font)
        self.le_azParkPos4.setMouseTracking(False)
        self.le_azParkPos4.setAcceptDrops(False)
        self.le_azParkPos4.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_azParkPos4.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_azParkPos4.setReadOnly(False)
        self.le_azParkPos4.setObjectName("le_azParkPos4")
        self.label_46 = QtWidgets.QLabel(self.tab_10)
        self.label_46.setGeometry(QtCore.QRect(260, 110, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_46.setFont(font)
        self.label_46.setObjectName("label_46")
        self.label_48 = QtWidgets.QLabel(self.tab_10)
        self.label_48.setGeometry(QtCore.QRect(330, 110, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_48.setFont(font)
        self.label_48.setObjectName("label_48")
        self.le_parkPos4Text = QtWidgets.QLineEdit(self.tab_10)
        self.le_parkPos4Text.setGeometry(QtCore.QRect(120, 140, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_parkPos4Text.setFont(font)
        self.le_parkPos4Text.setMouseTracking(False)
        self.le_parkPos4Text.setAcceptDrops(False)
        self.le_parkPos4Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_parkPos4Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.le_parkPos4Text.setReadOnly(False)
        self.le_parkPos4Text.setObjectName("le_parkPos4Text")
        self.label_47 = QtWidgets.QLabel(self.tab_10)
        self.label_47.setGeometry(QtCore.QRect(20, 110, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_47.setFont(font)
        self.label_47.setObjectName("label_47")
        self.le_azParkPos5 = QtWidgets.QLineEdit(self.tab_10)
        self.le_azParkPos5.setGeometry(QtCore.QRect(280, 170, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_azParkPos5.setFont(font)
        self.le_azParkPos5.setMouseTracking(False)
        self.le_azParkPos5.setAcceptDrops(False)
        self.le_azParkPos5.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_azParkPos5.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_azParkPos5.setReadOnly(False)
        self.le_azParkPos5.setObjectName("le_azParkPos5")
        self.label_92 = QtWidgets.QLabel(self.tab_10)
        self.label_92.setGeometry(QtCore.QRect(20, 200, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_92.setFont(font)
        self.label_92.setObjectName("label_92")
        self.le_altParkPos6 = QtWidgets.QLineEdit(self.tab_10)
        self.le_altParkPos6.setGeometry(QtCore.QRect(350, 200, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_altParkPos6.setFont(font)
        self.le_altParkPos6.setMouseTracking(False)
        self.le_altParkPos6.setAcceptDrops(False)
        self.le_altParkPos6.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_altParkPos6.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_altParkPos6.setReadOnly(False)
        self.le_altParkPos6.setObjectName("le_altParkPos6")
        self.label_93 = QtWidgets.QLabel(self.tab_10)
        self.label_93.setGeometry(QtCore.QRect(260, 170, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_93.setFont(font)
        self.label_93.setObjectName("label_93")
        self.label_94 = QtWidgets.QLabel(self.tab_10)
        self.label_94.setGeometry(QtCore.QRect(330, 170, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_94.setFont(font)
        self.label_94.setObjectName("label_94")
        self.label_95 = QtWidgets.QLabel(self.tab_10)
        self.label_95.setGeometry(QtCore.QRect(20, 170, 121, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_95.setFont(font)
        self.label_95.setObjectName("label_95")
        self.le_altParkPos5 = QtWidgets.QLineEdit(self.tab_10)
        self.le_altParkPos5.setGeometry(QtCore.QRect(350, 170, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_altParkPos5.setFont(font)
        self.le_altParkPos5.setMouseTracking(False)
        self.le_altParkPos5.setAcceptDrops(False)
        self.le_altParkPos5.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_altParkPos5.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_altParkPos5.setReadOnly(False)
        self.le_altParkPos5.setObjectName("le_altParkPos5")
        self.le_parkPos6Text = QtWidgets.QLineEdit(self.tab_10)
        self.le_parkPos6Text.setGeometry(QtCore.QRect(120, 200, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_parkPos6Text.setFont(font)
        self.le_parkPos6Text.setMouseTracking(False)
        self.le_parkPos6Text.setAcceptDrops(False)
        self.le_parkPos6Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_parkPos6Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.le_parkPos6Text.setReadOnly(False)
        self.le_parkPos6Text.setObjectName("le_parkPos6Text")
        self.le_parkPos5Text = QtWidgets.QLineEdit(self.tab_10)
        self.le_parkPos5Text.setGeometry(QtCore.QRect(120, 170, 121, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_parkPos5Text.setFont(font)
        self.le_parkPos5Text.setMouseTracking(False)
        self.le_parkPos5Text.setAcceptDrops(False)
        self.le_parkPos5Text.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_parkPos5Text.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.le_parkPos5Text.setReadOnly(False)
        self.le_parkPos5Text.setObjectName("le_parkPos5Text")
        self.label_131 = QtWidgets.QLabel(self.tab_10)
        self.label_131.setGeometry(QtCore.QRect(260, 200, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_131.setFont(font)
        self.label_131.setObjectName("label_131")
        self.label_132 = QtWidgets.QLabel(self.tab_10)
        self.label_132.setGeometry(QtCore.QRect(330, 200, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_132.setFont(font)
        self.label_132.setObjectName("label_132")
        self.le_azParkPos6 = QtWidgets.QLineEdit(self.tab_10)
        self.le_azParkPos6.setGeometry(QtCore.QRect(280, 200, 41, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_azParkPos6.setFont(font)
        self.le_azParkPos6.setMouseTracking(False)
        self.le_azParkPos6.setAcceptDrops(False)
        self.le_azParkPos6.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_azParkPos6.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_azParkPos6.setReadOnly(False)
        self.le_azParkPos6.setObjectName("le_azParkPos6")
        self.tabWidget_2.addTab(self.tab_10, "")
        self.tab_7 = QtWidgets.QWidget()
        self.tab_7.setObjectName("tab_7")
        self.btn_downloadEarthrotation = QtWidgets.QPushButton(self.tab_7)
        self.btn_downloadEarthrotation.setGeometry(QtCore.QRect(20, 50, 341, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_downloadEarthrotation.setFont(font)
        self.btn_downloadEarthrotation.setObjectName("btn_downloadEarthrotation")
        self.label_123 = QtWidgets.QLabel(self.tab_7)
        self.label_123.setGeometry(QtCore.QRect(20, 20, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_123.setFont(font)
        self.label_123.setObjectName("label_123")
        self.line_17 = QtWidgets.QFrame(self.tab_7)
        self.line_17.setGeometry(QtCore.QRect(20, 30, 341, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_17.setFont(font)
        self.line_17.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_17.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_17.setObjectName("line_17")
        self.btn_downloadSpacestations = QtWidgets.QPushButton(self.tab_7)
        self.btn_downloadSpacestations.setGeometry(QtCore.QRect(20, 90, 341, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_downloadSpacestations.setFont(font)
        self.btn_downloadSpacestations.setObjectName("btn_downloadSpacestations")
        self.btn_downloadSatbrighest = QtWidgets.QPushButton(self.tab_7)
        self.btn_downloadSatbrighest.setGeometry(QtCore.QRect(20, 130, 341, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_downloadSatbrighest.setFont(font)
        self.btn_downloadSatbrighest.setObjectName("btn_downloadSatbrighest")
        self.btn_downloadAsteroids = QtWidgets.QPushButton(self.tab_7)
        self.btn_downloadAsteroids.setGeometry(QtCore.QRect(20, 170, 341, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_downloadAsteroids.setFont(font)
        self.btn_downloadAsteroids.setObjectName("btn_downloadAsteroids")
        self.btn_downloadComets = QtWidgets.QPushButton(self.tab_7)
        self.btn_downloadComets.setGeometry(QtCore.QRect(20, 210, 341, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_downloadComets.setFont(font)
        self.btn_downloadComets.setObjectName("btn_downloadComets")
        self.checkEarthrotation = QtWidgets.QCheckBox(self.tab_7)
        self.checkEarthrotation.setGeometry(QtCore.QRect(410, 50, 301, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkEarthrotation.setFont(font)
        self.checkEarthrotation.setChecked(False)
        self.checkEarthrotation.setObjectName("checkEarthrotation")
        self.checkSpacestations = QtWidgets.QCheckBox(self.tab_7)
        self.checkSpacestations.setGeometry(QtCore.QRect(410, 90, 301, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkSpacestations.setFont(font)
        self.checkSpacestations.setChecked(False)
        self.checkSpacestations.setObjectName("checkSpacestations")
        self.checkSatellites = QtWidgets.QCheckBox(self.tab_7)
        self.checkSatellites.setGeometry(QtCore.QRect(410, 130, 301, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkSatellites.setFont(font)
        self.checkSatellites.setChecked(False)
        self.checkSatellites.setObjectName("checkSatellites")
        self.checkAsteroids = QtWidgets.QCheckBox(self.tab_7)
        self.checkAsteroids.setGeometry(QtCore.QRect(410, 170, 301, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkAsteroids.setFont(font)
        self.checkAsteroids.setChecked(False)
        self.checkAsteroids.setObjectName("checkAsteroids")
        self.checkComets = QtWidgets.QCheckBox(self.tab_7)
        self.checkComets.setGeometry(QtCore.QRect(410, 210, 301, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkComets.setFont(font)
        self.checkComets.setChecked(False)
        self.checkComets.setObjectName("checkComets")
        self.btn_uploadMount = QtWidgets.QPushButton(self.tab_7)
        self.btn_uploadMount.setGeometry(QtCore.QRect(400, 270, 311, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_uploadMount.setFont(font)
        self.btn_uploadMount.setObjectName("btn_uploadMount")
        self.btn_downloadAll = QtWidgets.QPushButton(self.tab_7)
        self.btn_downloadAll.setGeometry(QtCore.QRect(20, 270, 341, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_downloadAll.setFont(font)
        self.btn_downloadAll.setObjectName("btn_downloadAll")
        self.line_47 = QtWidgets.QFrame(self.tab_7)
        self.line_47.setGeometry(QtCore.QRect(370, 20, 21, 281))
        self.line_47.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_47.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_47.setObjectName("line_47")
        self.label_134 = QtWidgets.QLabel(self.tab_7)
        self.label_134.setGeometry(QtCore.QRect(400, 20, 171, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_134.setFont(font)
        self.label_134.setObjectName("label_134")
        self.line_19 = QtWidgets.QFrame(self.tab_7)
        self.line_19.setGeometry(QtCore.QRect(400, 30, 311, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_19.setFont(font)
        self.line_19.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_19.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_19.setObjectName("line_19")
        self.tabWidget_2.addTab(self.tab_7, "")
        self.tabWidget.addTab(self.tab_3, "")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.firmwareProductName_6 = QtWidgets.QLabel(self.tab)
        self.firmwareProductName_6.setGeometry(QtCore.QRect(10, 170, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.firmwareProductName_6.setFont(font)
        self.firmwareProductName_6.setObjectName("firmwareProductName_6")
        self.le_firmwareTime = QtWidgets.QLabel(self.tab)
        self.le_firmwareTime.setGeometry(QtCore.QRect(120, 140, 191, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        self.le_firmwareTime.setFont(font)
        self.le_firmwareTime.setObjectName("le_firmwareTime")
        self.le_hardwareVersion = QtWidgets.QLabel(self.tab)
        self.le_hardwareVersion.setGeometry(QtCore.QRect(120, 170, 201, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        self.le_hardwareVersion.setFont(font)
        self.le_hardwareVersion.setObjectName("le_hardwareVersion")
        self.le_firmwareProductName = QtWidgets.QLabel(self.tab)
        self.le_firmwareProductName.setGeometry(QtCore.QRect(120, 50, 191, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        self.le_firmwareProductName.setFont(font)
        self.le_firmwareProductName.setObjectName("le_firmwareProductName")
        self.firmwareProductName_5 = QtWidgets.QLabel(self.tab)
        self.firmwareProductName_5.setGeometry(QtCore.QRect(10, 140, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.firmwareProductName_5.setFont(font)
        self.firmwareProductName_5.setObjectName("firmwareProductName_5")
        self.firmwareProductName_4 = QtWidgets.QLabel(self.tab)
        self.firmwareProductName_4.setGeometry(QtCore.QRect(10, 110, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.firmwareProductName_4.setFont(font)
        self.firmwareProductName_4.setObjectName("firmwareProductName_4")
        self.le_firmwareNumber = QtWidgets.QLabel(self.tab)
        self.le_firmwareNumber.setGeometry(QtCore.QRect(120, 80, 191, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        self.le_firmwareNumber.setFont(font)
        self.le_firmwareNumber.setObjectName("le_firmwareNumber")
        self.firmwareProductName_2 = QtWidgets.QLabel(self.tab)
        self.firmwareProductName_2.setGeometry(QtCore.QRect(10, 50, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.firmwareProductName_2.setFont(font)
        self.firmwareProductName_2.setObjectName("firmwareProductName_2")
        self.le_firmwareDate = QtWidgets.QLabel(self.tab)
        self.le_firmwareDate.setGeometry(QtCore.QRect(120, 110, 191, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        self.le_firmwareDate.setFont(font)
        self.le_firmwareDate.setObjectName("le_firmwareDate")
        self.firmwareProductName_3 = QtWidgets.QLabel(self.tab)
        self.firmwareProductName_3.setGeometry(QtCore.QRect(10, 80, 101, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.firmwareProductName_3.setFont(font)
        self.firmwareProductName_3.setObjectName("firmwareProductName_3")
        self.line_6 = QtWidgets.QFrame(self.tab)
        self.line_6.setGeometry(QtCore.QRect(10, 30, 331, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.line_6.setFont(font)
        self.line_6.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_6.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_6.setObjectName("line_6")
        self.label_56 = QtWidgets.QLabel(self.tab)
        self.label_56.setGeometry(QtCore.QRect(10, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_56.setFont(font)
        self.label_56.setObjectName("label_56")
        self.firmwareProductName_7 = QtWidgets.QLabel(self.tab)
        self.firmwareProductName_7.setGeometry(QtCore.QRect(10, 250, 271, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.firmwareProductName_7.setFont(font)
        self.firmwareProductName_7.setObjectName("firmwareProductName_7")
        self.le_mwWorkingDir = QtWidgets.QLabel(self.tab)
        self.le_mwWorkingDir.setGeometry(QtCore.QRect(10, 270, 741, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        self.le_mwWorkingDir.setFont(font)
        self.le_mwWorkingDir.setObjectName("le_mwWorkingDir")
        self.le_firmwareProductName_2 = QtWidgets.QLabel(self.tab)
        self.le_firmwareProductName_2.setGeometry(QtCore.QRect(410, 450, 271, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        self.le_firmwareProductName_2.setFont(font)
        self.le_firmwareProductName_2.setObjectName("le_firmwareProductName_2")
        self.build = QtWidgets.QLabel(self.tab)
        self.build.setGeometry(QtCore.QRect(690, 450, 51, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        self.build.setFont(font)
        self.build.setObjectName("build")
        self.tabWidget.addTab(self.tab, "")
        self.tab_9 = QtWidgets.QWidget()
        self.tab_9.setObjectName("tab_9")
        self.le_ipRelaybox = QtWidgets.QLineEdit(self.tab_9)
        self.le_ipRelaybox.setGeometry(QtCore.QRect(110, 170, 141, 21))
        font = QtGui.QFont()
        font.setFamily("Courier")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.le_ipRelaybox.setFont(font)
        self.le_ipRelaybox.setMouseTracking(False)
        self.le_ipRelaybox.setFocusPolicy(QtCore.Qt.NoFocus)
        self.le_ipRelaybox.setAcceptDrops(False)
        self.le_ipRelaybox.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.le_ipRelaybox.setInputMask("")
        self.le_ipRelaybox.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.le_ipRelaybox.setReadOnly(False)
        self.le_ipRelaybox.setObjectName("le_ipRelaybox")
        self.line_31 = QtWidgets.QFrame(self.tab_9)
        self.line_31.setGeometry(QtCore.QRect(20, 30, 271, 21))
        self.line_31.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_31.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_31.setObjectName("line_31")
        self.btn_bootMount = QtWidgets.QPushButton(self.tab_9)
        self.btn_bootMount.setGeometry(QtCore.QRect(20, 50, 131, 31))
        self.btn_bootMount.setObjectName("btn_bootMount")
        self.btn_switchHeater = QtWidgets.QPushButton(self.tab_9)
        self.btn_switchHeater.setGeometry(QtCore.QRect(20, 130, 131, 31))
        self.btn_switchHeater.setObjectName("btn_switchHeater")
        self.btn_switchCCD = QtWidgets.QPushButton(self.tab_9)
        self.btn_switchCCD.setGeometry(QtCore.QRect(20, 90, 131, 31))
        self.btn_switchCCD.setObjectName("btn_switchCCD")
        self.label_97 = QtWidgets.QLabel(self.tab_9)
        self.label_97.setGeometry(QtCore.QRect(20, 170, 81, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_97.setFont(font)
        self.label_97.setObjectName("label_97")
        self.label_96 = QtWidgets.QLabel(self.tab_9)
        self.label_96.setGeometry(QtCore.QRect(20, 20, 161, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_96.setFont(font)
        self.label_96.setObjectName("label_96")
        self.tabWidget.addTab(self.tab_9, "")
        self.btn_shutdownQuit = QtWidgets.QPushButton(WizzardMainDialog)
        self.btn_shutdownQuit.setGeometry(QtCore.QRect(10, 110, 111, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_shutdownQuit.setFont(font)
        self.btn_shutdownQuit.setObjectName("btn_shutdownQuit")
        self.windowTitle = QtWidgets.QLabel(WizzardMainDialog)
        self.windowTitle.setGeometry(QtCore.QRect(0, 0, 791, 31))
        font = QtGui.QFont()
        font.setFamily("MS Shell Dlg 2")
        font.setPointSize(12)
        font.setBold(True)
        font.setWeight(75)
        self.windowTitle.setFont(font)
        self.windowTitle.setAutoFillBackground(True)
        self.windowTitle.setAlignment(QtCore.Qt.AlignCenter)
        self.windowTitle.setObjectName("windowTitle")
        self.btn_mountQuit = QtWidgets.QPushButton(WizzardMainDialog)
        self.btn_mountQuit.setGeometry(QtCore.QRect(240, 110, 111, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountQuit.setFont(font)
        self.btn_mountQuit.setObjectName("btn_mountQuit")
        self.errorStatus = QtWidgets.QTextBrowser(WizzardMainDialog)
        self.errorStatus.setGeometry(QtCore.QRect(360, 60, 411, 81))
        font = QtGui.QFont()
        font.setFamily("MS Shell Dlg 2")
        font.setPointSize(8)
        self.errorStatus.setFont(font)
        self.errorStatus.setFrameShadow(QtWidgets.QFrame.Plain)
        self.errorStatus.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustToContents)
        self.errorStatus.setAcceptRichText(False)
        self.errorStatus.setObjectName("errorStatus")
        self.label_104 = QtWidgets.QLabel(WizzardMainDialog)
        self.label_104.setGeometry(QtCore.QRect(360, 40, 171, 16))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_104.setFont(font)
        self.label_104.setObjectName("label_104")
        self.btn_selectClose = QtWidgets.QPushButton(WizzardMainDialog)
        self.btn_selectClose.setGeometry(QtCore.QRect(750, 0, 41, 31))
        font = QtGui.QFont()
        font.setFamily("MS Shell Dlg 2")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.btn_selectClose.setFont(font)
        self.btn_selectClose.setObjectName("btn_selectClose")
        self.btn_mountSave = QtWidgets.QPushButton(WizzardMainDialog)
        self.btn_mountSave.setGeometry(QtCore.QRect(130, 110, 101, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_mountSave.setFont(font)
        self.btn_mountSave.setObjectName("btn_mountSave")
        self.btn_camPlateConnected = QtWidgets.QPushButton(WizzardMainDialog)
        self.btn_camPlateConnected.setGeometry(QtCore.QRect(290, 40, 61, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_camPlateConnected.setFont(font)
        self.btn_camPlateConnected.setObjectName("btn_camPlateConnected")
        self.btn_domeConnected = QtWidgets.QPushButton(WizzardMainDialog)
        self.btn_domeConnected.setGeometry(QtCore.QRect(80, 40, 61, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_domeConnected.setFont(font)
        self.btn_domeConnected.setObjectName("btn_domeConnected")
        self.btn_driverMountConnected = QtWidgets.QPushButton(WizzardMainDialog)
        self.btn_driverMountConnected.setGeometry(QtCore.QRect(10, 40, 61, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_driverMountConnected.setFont(font)
        self.btn_driverMountConnected.setObjectName("btn_driverMountConnected")
        self.btn_driverWeatherConnected = QtWidgets.QPushButton(WizzardMainDialog)
        self.btn_driverWeatherConnected.setGeometry(QtCore.QRect(220, 40, 61, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_driverWeatherConnected.setFont(font)
        self.btn_driverWeatherConnected.setObjectName("btn_driverWeatherConnected")
        self.btn_driverStickConnected = QtWidgets.QPushButton(WizzardMainDialog)
        self.btn_driverStickConnected.setGeometry(QtCore.QRect(150, 40, 61, 31))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.btn_driverStickConnected.setFont(font)
        self.btn_driverStickConnected.setObjectName("btn_driverStickConnected")

        self.retranslateUi(WizzardMainDialog)
        self.tabWidget.setCurrentIndex(0)
        self.tabWidget_2.setCurrentIndex(4)
        QtCore.QMetaObject.connectSlotsByName(WizzardMainDialog)
        WizzardMainDialog.setTabOrder(self.btn_setDualTracking, self.btn_setUnattendedFlip)
        WizzardMainDialog.setTabOrder(self.btn_setUnattendedFlip, self.altitudeBase)
        WizzardMainDialog.setTabOrder(self.altitudeBase, self.azimuthBase)
        WizzardMainDialog.setTabOrder(self.azimuthBase, self.checkUseBlindSolve)
        WizzardMainDialog.setTabOrder(self.checkUseBlindSolve, self.targetRMS)
        WizzardMainDialog.setTabOrder(self.targetRMS, self.le_horizonLimitLow)
        WizzardMainDialog.setTabOrder(self.le_horizonLimitLow, self.btn_setHorizonLimitLow)
        WizzardMainDialog.setTabOrder(self.btn_setHorizonLimitLow, self.le_horizonLimitHigh)
        WizzardMainDialog.setTabOrder(self.le_horizonLimitHigh, self.btn_setHorizonLimitHigh)
        WizzardMainDialog.setTabOrder(self.btn_setHorizonLimitHigh, self.btn_setRefractionCorrection)
        WizzardMainDialog.setTabOrder(self.btn_setRefractionCorrection, self.btn_setRefractionParameters)
        WizzardMainDialog.setTabOrder(self.btn_setRefractionParameters, self.checkAutoRefraction)
        WizzardMainDialog.setTabOrder(self.checkAutoRefraction, self.alignErrorStars)
        WizzardMainDialog.setTabOrder(self.alignErrorStars, self.btn_showActualModel)
        WizzardMainDialog.setTabOrder(self.btn_showActualModel, self.btn_runTargetRMSAlignment)
        WizzardMainDialog.setTabOrder(self.btn_runTargetRMSAlignment, self.btn_saveBackupModel)
        WizzardMainDialog.setTabOrder(self.btn_saveBackupModel, self.btn_loadBackupModel)
        WizzardMainDialog.setTabOrder(self.btn_loadBackupModel, self.btn_loadSimpleModel)
        WizzardMainDialog.setTabOrder(self.btn_loadSimpleModel, self.btn_saveSimpleModel)
        WizzardMainDialog.setTabOrder(self.btn_saveSimpleModel, self.btn_clearAlignmentModel)
        WizzardMainDialog.setTabOrder(self.btn_clearAlignmentModel, self.btn_generateBasePoints)
        WizzardMainDialog.setTabOrder(self.btn_generateBasePoints, self.btn_mountQuit)
        WizzardMainDialog.setTabOrder(self.btn_mountQuit, self.btn_shutdownQuit)
        WizzardMainDialog.setTabOrder(self.btn_shutdownQuit, self.le_meridianLimitTrack)
        WizzardMainDialog.setTabOrder(self.le_meridianLimitTrack, self.btn_loadBasePoints)
        WizzardMainDialog.setTabOrder(self.btn_loadBasePoints, self.btn_mountPark)
        WizzardMainDialog.setTabOrder(self.btn_mountPark, self.btn_startTracking)
        WizzardMainDialog.setTabOrder(self.btn_startTracking, self.tabWidget)
        WizzardMainDialog.setTabOrder(self.tabWidget, self.errorStatus)
        WizzardMainDialog.setTabOrder(self.errorStatus, self.le_telescopeDualTrack)
        WizzardMainDialog.setTabOrder(self.le_telescopeDualTrack, self.le_telescopeUnattendedFlip)
        WizzardMainDialog.setTabOrder(self.le_telescopeUnattendedFlip, self.btn_mountPos4)
        WizzardMainDialog.setTabOrder(self.btn_mountPos4, self.btn_mountUnpark)
        WizzardMainDialog.setTabOrder(self.btn_mountUnpark, self.btn_mountPos2)
        WizzardMainDialog.setTabOrder(self.btn_mountPos2, self.btn_stop)
        WizzardMainDialog.setTabOrder(self.btn_stop, self.btn_stopTracking)
        WizzardMainDialog.setTabOrder(self.btn_stopTracking, self.btn_setTrackingSideral)
        WizzardMainDialog.setTabOrder(self.btn_setTrackingSideral, self.btn_runBaseModel)
        WizzardMainDialog.setTabOrder(self.btn_runBaseModel, self.btn_mountPos3)
        WizzardMainDialog.setTabOrder(self.btn_mountPos3, self.btn_setTrackingLunar)
        WizzardMainDialog.setTabOrder(self.btn_setTrackingLunar, self.btn_mountPos1)
        WizzardMainDialog.setTabOrder(self.btn_mountPos1, self.btn_setTrackingSolar)
        WizzardMainDialog.setTabOrder(self.btn_setTrackingSolar, self.btn_flipMount)

    def retranslateUi(self, WizzardMainDialog):
        _translate = QtCore.QCoreApplication.translate
        WizzardMainDialog.setWindowTitle(_translate("WizzardMainDialog", "Mount Command Window (C) MW 2016"))
        self.le_mountStatus.setToolTip(_translate("WizzardMainDialog", "Status feedback from mount "))
        self.le_mountStatus.setText(_translate("WizzardMainDialog", "Mount Status"))
        self.tabWidget.setToolTip(_translate("WizzardMainDialog", "Tab section"))
        self.le_telescopeRA.setText(_translate("WizzardMainDialog", "RA"))
        self.le_telescopeAzimut.setText(_translate("WizzardMainDialog", "AZ"))
        self.le_telescopeDEC.setText(_translate("WizzardMainDialog", "DEC"))
        self.le_telescopeAltitude.setText(_translate("WizzardMainDialog", "ALT"))
        self.label_9.setText(_translate("WizzardMainDialog", "Telescope AZ (Deg)"))
        self.label_10.setText(_translate("WizzardMainDialog", "Telescope DEC (DMS)"))
        self.label_8.setText(_translate("WizzardMainDialog", "Telescope ALT (Deg)"))
        self.label_11.setText(_translate("WizzardMainDialog", "Telescope RA (HMS)"))
        self.label_17.setText(_translate("WizzardMainDialog", "Max. Slew Rate"))
        self.le_meridianLimitTrack.setInputMask(_translate("WizzardMainDialog", "#9"))
        self.le_meridianLimitTrack.setText(_translate("WizzardMainDialog", "10"))
        self.le_telescopePierSide.setToolTip(_translate("WizzardMainDialog", "Pier side"))
        self.le_telescopePierSide.setText(_translate("WizzardMainDialog", "WEST"))
        self.label_18.setText(_translate("WizzardMainDialog", "Pier"))
        self.label_21.setText(_translate("WizzardMainDialog", "Dual Tracking"))
        self.le_telescopeDualTrack.setToolTip(_translate("WizzardMainDialog", "Status of dual tracking"))
        self.le_telescopeDualTrack.setText(_translate("WizzardMainDialog", "ON"))
        self.btn_setDualTracking.setToolTip(_translate("WizzardMainDialog", "Sets dual tracking on / off"))
        self.btn_setDualTracking.setText(_translate("WizzardMainDialog", "I/O"))
        self.label_52.setText(_translate("WizzardMainDialog", "Time to flip"))
        self.le_timeToFlip.setToolTip(_translate("WizzardMainDialog", "Time until tracking ends because of flip / horizon limit"))
        self.le_timeToFlip.setText(_translate("WizzardMainDialog", "1234"))
        self.btn_setUnattendedFlip.setToolTip(_translate("WizzardMainDialog", "Sets unattended flip on / off"))
        self.btn_setUnattendedFlip.setText(_translate("WizzardMainDialog", "I/O"))
        self.le_telescopeUnattendedFlip.setToolTip(_translate("WizzardMainDialog", "Status of unattended Flip"))
        self.le_telescopeUnattendedFlip.setText(_translate("WizzardMainDialog", "ON"))
        self.label_23.setText(_translate("WizzardMainDialog", "Unattended Flip"))
        self.label_61.setText(_translate("WizzardMainDialog", "min"))
        self.label_62.setText(_translate("WizzardMainDialog", "°/s"))
        self.label_80.setText(_translate("WizzardMainDialog", "Tracking / Slewing  Settings"))
        self.label_81.setText(_translate("WizzardMainDialog", "Pointing Coordinates"))
        self.btn_startTracking.setToolTip(_translate("WizzardMainDialog", "Start tracking the mount"))
        self.btn_startTracking.setText(_translate("WizzardMainDialog", "Start Tracking"))
        self.btn_mountPark.setToolTip(_translate("WizzardMainDialog", "PArk mount in default position"))
        self.btn_mountPark.setText(_translate("WizzardMainDialog", "Park"))
        self.btn_mountUnpark.setToolTip(_translate("WizzardMainDialog", "Unpark the mount"))
        self.btn_mountUnpark.setText(_translate("WizzardMainDialog", "Unpark"))
        self.label_83.setText(_translate("WizzardMainDialog", "Defined Positions"))
        self.label_84.setText(_translate("WizzardMainDialog", "Tracking"))
        self.btn_mountPos4.setText(_translate("WizzardMainDialog", "Park Pos4"))
        self.label_85.setText(_translate("WizzardMainDialog", "Parking"))
        self.btn_mountPos2.setText(_translate("WizzardMainDialog", "Park Pos2"))
        self.btn_mountPos3.setText(_translate("WizzardMainDialog", "Park Pos3"))
        self.btn_mountPos1.setText(_translate("WizzardMainDialog", "Park Pos1"))
        self.btn_stopTracking.setToolTip(_translate("WizzardMainDialog", "Stop tracking mount"))
        self.btn_stopTracking.setText(_translate("WizzardMainDialog", "Stop Tracking"))
        self.btn_stop.setToolTip(_translate("WizzardMainDialog", "Stops all mount movements immediatly"))
        self.btn_stop.setText(_translate("WizzardMainDialog", "STOP MOUNT"))
        self.btn_flipMount.setToolTip(_translate("WizzardMainDialog", "Flips the mount if possible"))
        self.btn_flipMount.setText(_translate("WizzardMainDialog", "Flip !"))
        self.btn_setTrackingLunar.setToolTip(_translate("WizzardMainDialog", "Set tracking speed to lunar"))
        self.btn_setTrackingLunar.setText(_translate("WizzardMainDialog", "Lunar"))
        self.btn_setTrackingSolar.setToolTip(_translate("WizzardMainDialog", "Set tracking speed to solar"))
        self.btn_setTrackingSolar.setText(_translate("WizzardMainDialog", "Solar"))
        self.btn_setTrackingSideral.setToolTip(_translate("WizzardMainDialog", "Set tracking speed to sideral"))
        self.btn_setTrackingSideral.setText(_translate("WizzardMainDialog", "Sideral"))
        self.label_100.setText(_translate("WizzardMainDialog", "side"))
        self.label_34.setText(_translate("WizzardMainDialog", "Meridian Limit Track"))
        self.label_65.setText(_translate("WizzardMainDialog", "Meridian Limit Slew"))
        self.le_meridianLimitSlew.setInputMask(_translate("WizzardMainDialog", "#9"))
        self.le_meridianLimitSlew.setText(_translate("WizzardMainDialog", "10"))
        self.label_88.setText(_translate("WizzardMainDialog", "°"))
        self.label_89.setText(_translate("WizzardMainDialog", "°"))
        self.le_slewRate.setInputMask(_translate("WizzardMainDialog", "#9"))
        self.le_slewRate.setText(_translate("WizzardMainDialog", "10"))
        self.label_90.setText(_translate("WizzardMainDialog", "Time to meridian"))
        self.le_timeToMeridian.setToolTip(_translate("WizzardMainDialog", "Time until tracking ends because of flip / horizon limit"))
        self.le_timeToMeridian.setText(_translate("WizzardMainDialog", "1234"))
        self.label_91.setText(_translate("WizzardMainDialog", "min"))
        self.btn_mountPos6.setText(_translate("WizzardMainDialog", "Park Pos6"))
        self.btn_mountPos5.setText(_translate("WizzardMainDialog", "Park Pos5"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("WizzardMainDialog", "Pointing"))
        self.btn_runBaseModel.setToolTip(_translate("WizzardMainDialog", "Runs the base model, if ther are any points"))
        self.btn_runBaseModel.setText(_translate("WizzardMainDialog", "Run Base Model"))
        self.checkUseBlindSolve.setToolTip(_translate("WizzardMainDialog", "If checked, a blind solve would be made (needs internet connection)"))
        self.checkUseBlindSolve.setText(_translate("WizzardMainDialog", "Use Blind Solve"))
        self.btn_clearAlignmentModel.setToolTip(_translate("WizzardMainDialog", "Clear the model in mount. Can\'t be revised."))
        self.btn_clearAlignmentModel.setText(_translate("WizzardMainDialog", "Clear Model"))
        self.btn_loadBasePoints.setToolTip(_translate("WizzardMainDialog", "Shows the base points of model point file"))
        self.btn_loadBasePoints.setText(_translate("WizzardMainDialog", "Show Base Points"))
        self.btn_generateBasePoints.setToolTip(_translate("WizzardMainDialog", "Generates Basepoint based on Altitude and AZ"))
        self.btn_generateBasePoints.setText(_translate("WizzardMainDialog", "Generate Basepoints"))
        self.label_170.setText(_translate("WizzardMainDialog", "Altitude"))
        self.label_171.setText(_translate("WizzardMainDialog", "Azimuth"))
        self.label_103.setText(_translate("WizzardMainDialog", "Base Modeling Run"))
        self.label_109.setText(_translate("WizzardMainDialog", "°"))
        self.label_110.setText(_translate("WizzardMainDialog", "°"))
        self.label_116.setText(_translate("WizzardMainDialog", "Generate Base Points"))
        self.btn_openCoordinateWindow.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Opens the coordinate an model points popup window</p></body></html>"))
        self.btn_openCoordinateWindow.setText(_translate("WizzardMainDialog", "Open Modeling Plot Window"))
        self.btn_sortRefinementPoints.setToolTip(_translate("WizzardMainDialog", "Sort the order of modeling points. East-West-Low-High Altitude"))
        self.btn_sortRefinementPoints.setText(_translate("WizzardMainDialog", "Sort East/West"))
        self.btn_generateGridPoints.setToolTip(_translate("WizzardMainDialog", "Generates a regular pattern with 100 stars"))
        self.btn_generateGridPoints.setText(_translate("WizzardMainDialog", "Grid Points"))
        self.label_108.setText(_translate("WizzardMainDialog", "Generate Refinement Points"))
        self.label_179.setText(_translate("WizzardMainDialog", "Columns"))
        self.label_178.setText(_translate("WizzardMainDialog", "Rows"))
        self.btn_generateNormalPoints.setToolTip(_translate("WizzardMainDialog", "Generates a pointcloud with greater circles medium number"))
        self.btn_generateNormalPoints.setText(_translate("WizzardMainDialog", "Pointcloud Normal"))
        self.btn_generateDensePoints.setToolTip(_translate("WizzardMainDialog", "Generates a pointcloud with greater circles high number"))
        self.btn_generateDensePoints.setText(_translate("WizzardMainDialog", "Pointcloud Dense"))
        self.numberGridPointsRow.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Number of rows in the grid build</p></body></html>"))
        self.numberGridPointsCol.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Number of coloms in the grid build</p></body></html>"))
        self.btn_runRefinementModel.setToolTip(_translate("WizzardMainDialog", "Run refinment model"))
        self.btn_runRefinementModel.setText(_translate("WizzardMainDialog", "Run Refinement Model"))
        self.btn_deleteBelowHorizonLine.setToolTip(_translate("WizzardMainDialog", "Delete all points below the horizon line from horizone file"))
        self.btn_deleteBelowHorizonLine.setText(_translate("WizzardMainDialog", "Delete all Points below Horizon"))
        self.btn_loadRefinementPoints.setToolTip(_translate("WizzardMainDialog", "Shows the refinment point of the model point file."))
        self.btn_loadRefinementPoints.setText(_translate("WizzardMainDialog", "Show Refine Points"))
        self.label_101.setText(_translate("WizzardMainDialog", "Refinement Modeling Run"))
        self.btn_cancelModel.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Cancels any model run in the next cycle (next point)</p></body></html>"))
        self.btn_cancelModel.setText(_translate("WizzardMainDialog", "Cancel any Model Run"))
        self.btn_runCheckModel.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Runs a analyse cycle without updating the mount model</p></body></html>"))
        self.btn_runCheckModel.setText(_translate("WizzardMainDialog", "Run Analyse (Base & Refine)"))
        self.label_98.setText(_translate("WizzardMainDialog", "Analyse - (including Base & Refine)"))
        self.btn_generateDSOPoints.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Generates a given number of refinement points along DSO track for a give time</p></body></html>"))
        self.btn_generateDSOPoints.setText(_translate("WizzardMainDialog", "Generate DSO Track"))
        self.label_113.setText(_translate("WizzardMainDialog", "General Functions"))
        self.btn_deletePoints.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Delete all points on coordinate window including Base / Model</p></body></html>"))
        self.btn_deletePoints.setText(_translate("WizzardMainDialog", "Clear Modeling Plot Window"))
        self.btn_runAllModel.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Run base and refinement model directly after another</p></body></html>"))
        self.btn_runAllModel.setText(_translate("WizzardMainDialog", "Run Base and Refinement Model"))
        self.numberHoursDSO.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Length of the DSO track in hours.</p></body></html>"))
        self.label_181.setText(_translate("WizzardMainDialog", "Hours"))
        self.label_188.setText(_translate("WizzardMainDialog", "Points"))
        self.numberPointsDSO.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Number of points in the DSO track for the given time in hours</p></body></html>"))
        self.label_189.setText(_translate("WizzardMainDialog", "TimeShift [h]"))
        self.numberHoursPreview.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Length of the DSO track in hours.</p></body></html>"))
        self.checkRunTrackingWidget.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Checked if you would like to see the tracking line and flip time in the window</p></body></html>"))
        self.checkRunTrackingWidget.setText(_translate("WizzardMainDialog", "Show Tracking in Model Plot Window"))
        self.btn_plateSolveSync.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Image, Platesolve and Sync the model of the mount</p></body></html>"))
        self.btn_plateSolveSync.setText(_translate("WizzardMainDialog", "Plate Solve and Sync Model"))
        self.checkClearModelFirst.setToolTip(_translate("WizzardMainDialog", "If checked, a blind solve would be made (needs internet connection)"))
        self.checkClearModelFirst.setText(_translate("WizzardMainDialog", "Clear Model first"))
        self.checkKeepRefinement.setToolTip(_translate("WizzardMainDialog", "If checked, a blind solve would be made (needs internet connection)"))
        self.checkKeepRefinement.setText(_translate("WizzardMainDialog", "Keep Refinement model"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_6), _translate("WizzardMainDialog", "Modeling Base / Refine"))
        self.label_107.setText(_translate("WizzardMainDialog", "Analyse - Time based deviations"))
        self.btn_cancelAnalyseModel.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Cancels a analyse cycle by constant pointing alt/az and measuring the error (next point)</p></body></html>"))
        self.btn_cancelAnalyseModel.setText(_translate("WizzardMainDialog", "Cancel Analyse Run"))
        self.btn_runTimeChangeModel.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Runs a analyse cycle by constant pointing alt/az and measuring the error</p></body></html>"))
        self.btn_runTimeChangeModel.setText(_translate("WizzardMainDialog", "Run"))
        self.label_174.setText(_translate("WizzardMainDialog", "Altitude"))
        self.label_175.setText(_translate("WizzardMainDialog", "Azimuth"))
        self.label_176.setText(_translate("WizzardMainDialog", "Number of runs"))
        self.label_111.setText(_translate("WizzardMainDialog", "°"))
        self.label_112.setText(_translate("WizzardMainDialog", "°"))
        self.label_177.setText(_translate("WizzardMainDialog", "Delay"))
        self.label_115.setText(_translate("WizzardMainDialog", "s"))
        self.label_118.setText(_translate("WizzardMainDialog", "Analyse - Hysterese"))
        self.btn_runHystereseModel.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Runs a analyse cycle by swapping two alt/az positions and measuring the error</p></body></html>"))
        self.btn_runHystereseModel.setText(_translate("WizzardMainDialog", "Run"))
        self.le_analyseFileName.setToolTip(_translate("WizzardMainDialog", "Name of Analysis file, where the data ist stored"))
        self.btn_openAnalyseWindow.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Opens the analyse Popup Window</p></body></html>"))
        self.btn_openAnalyseWindow.setText(_translate("WizzardMainDialog", "Open Analyse Window"))
        self.btn_selectAnalyseFileName.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Selects the file, where the analyse data is stored</p></body></html>"))
        self.btn_selectAnalyseFileName.setText(_translate("WizzardMainDialog", "Select File"))
        self.label_99.setText(_translate("WizzardMainDialog", "Select Analyse File"))
        self.label_182.setText(_translate("WizzardMainDialog", "Azimuth"))
        self.label_183.setText(_translate("WizzardMainDialog", "Number of runs"))
        self.label_184.setText(_translate("WizzardMainDialog", "Delay"))
        self.label_117.setText(_translate("WizzardMainDialog", "s"))
        self.label_114.setText(_translate("WizzardMainDialog", "°"))
        self.label_119.setText(_translate("WizzardMainDialog", "°"))
        self.label_185.setText(_translate("WizzardMainDialog", "Point 1    Altitude"))
        self.label_120.setText(_translate("WizzardMainDialog", "°"))
        self.label_121.setText(_translate("WizzardMainDialog", "°"))
        self.label_186.setText(_translate("WizzardMainDialog", "Azimuth"))
        self.label_187.setText(_translate("WizzardMainDialog", "Point 2    Altitude"))
        self.btn_runBatchModel.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Generates a new pointing model from stored analyse data</p></body></html>"))
        self.btn_runBatchModel.setText(_translate("WizzardMainDialog", "Make Mount Model from stored Analyse Data"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_5), _translate("WizzardMainDialog", "Model Analyse"))
        self.le_alignNumberStars.setToolTip(_translate("WizzardMainDialog", "Number of alignment stars in actual used pointing model"))
        self.le_alignNumberStars.setText(_translate("WizzardMainDialog", "10"))
        self.label.setText(_translate("WizzardMainDialog", "Stars"))
        self.le_alignError.setToolTip(_translate("WizzardMainDialog", "Number of alignment stars in actual used pointing model"))
        self.le_alignError.setText(_translate("WizzardMainDialog", "10.0"))
        self.label_14.setText(_translate("WizzardMainDialog", "RMS"))
        self.btn_showActualModel.setToolTip(_translate("WizzardMainDialog", "Download actual model from mount"))
        self.btn_showActualModel.setText(_translate("WizzardMainDialog", "Show Actual Model"))
        self.label_37.setText(_translate("WizzardMainDialog", "Target"))
        self.btn_runTargetRMSAlignment.setToolTip(_translate("WizzardMainDialog", "Deletes worst point of actual model until error is below target RMS"))
        self.btn_runTargetRMSAlignment.setText(_translate("WizzardMainDialog", "Run Optimize"))
        self.btn_saveBackupModel.setToolTip(_translate("WizzardMainDialog", "Saves actual model und name \"BACKUP\" in mount"))
        self.btn_saveBackupModel.setText(_translate("WizzardMainDialog", "Save"))
        self.btn_loadBackupModel.setToolTip(_translate("WizzardMainDialog", "Restores the actual model from stored model with name \"BACKUP\""))
        self.btn_loadBackupModel.setText(_translate("WizzardMainDialog", "Load"))
        self.btn_loadSimpleModel.setToolTip(_translate("WizzardMainDialog", "Restores the actual model from stored model with name \"SIMPLE\""))
        self.btn_loadSimpleModel.setText(_translate("WizzardMainDialog", "Load"))
        self.btn_saveSimpleModel.setToolTip(_translate("WizzardMainDialog", "Saves actual model und name \"SIMPLE\" in mount"))
        self.btn_saveSimpleModel.setText(_translate("WizzardMainDialog", "Save"))
        self.btn_deleteWorstPoint.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Deletes worst point of actual model.</p></body></html>"))
        self.btn_deleteWorstPoint.setText(_translate("WizzardMainDialog", "Delete worst Point"))
        self.label_124.setText(_translate("WizzardMainDialog", "Optimize Actual Model"))
        self.label_125.setText(_translate("WizzardMainDialog", "Load / Save Model in Mount Controller"))
        self.btn_loadBaseModel.setToolTip(_translate("WizzardMainDialog", "Restores the actual model from stored model with name \"SIMPLE\""))
        self.btn_loadBaseModel.setText(_translate("WizzardMainDialog", "Load"))
        self.btn_saveBaseModel.setToolTip(_translate("WizzardMainDialog", "Saves actual model und name \"SIMPLE\" in mount"))
        self.btn_saveBaseModel.setText(_translate("WizzardMainDialog", "Save"))
        self.label_126.setText(_translate("WizzardMainDialog", "BACKUP"))
        self.label_127.setText(_translate("WizzardMainDialog", "BASE"))
        self.label_128.setText(_translate("WizzardMainDialog", "SIMPLE"))
        self.btn_saveDSO1Model.setToolTip(_translate("WizzardMainDialog", "Saves actual model und name \"SIMPLE\" in mount"))
        self.btn_saveDSO1Model.setText(_translate("WizzardMainDialog", "Save"))
        self.btn_loadDSO1Model.setToolTip(_translate("WizzardMainDialog", "Restores the actual model from stored model with name \"SIMPLE\""))
        self.btn_loadDSO1Model.setText(_translate("WizzardMainDialog", "Load"))
        self.btn_saveDSO2Model.setToolTip(_translate("WizzardMainDialog", "Saves actual model und name \"SIMPLE\" in mount"))
        self.btn_saveDSO2Model.setText(_translate("WizzardMainDialog", "Save"))
        self.btn_loadDSO2Model.setToolTip(_translate("WizzardMainDialog", "Restores the actual model from stored model with name \"SIMPLE\""))
        self.btn_loadDSO2Model.setText(_translate("WizzardMainDialog", "Load"))
        self.label_129.setText(_translate("WizzardMainDialog", "DSO 1"))
        self.label_130.setText(_translate("WizzardMainDialog", "DSO 2"))
        self.btn_saveRefinementModel.setToolTip(_translate("WizzardMainDialog", "Saves actual model und name \"SIMPLE\" in mount"))
        self.btn_saveRefinementModel.setText(_translate("WizzardMainDialog", "Save"))
        self.label_133.setText(_translate("WizzardMainDialog", "REFINE"))
        self.btn_loadRefinementModel.setToolTip(_translate("WizzardMainDialog", "Restores the actual model from stored model with name \"SIMPLE\""))
        self.btn_loadRefinementModel.setText(_translate("WizzardMainDialog", "Load"))
        self.checkPolarPlot.setToolTip(_translate("WizzardMainDialog", "If checked, a blind solve would be made (needs internet connection)"))
        self.checkPolarPlot.setText(_translate("WizzardMainDialog", "Polar Plot"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_8), _translate("WizzardMainDialog", "Model Management"))
        self.le_siteElevation.setText(_translate("WizzardMainDialog", "0000.0"))
        self.label_5.setText(_translate("WizzardMainDialog", "Site Longitude"))
        self.le_siteLongitude.setText(_translate("WizzardMainDialog", "0000000000"))
        self.label_6.setText(_translate("WizzardMainDialog", "Site Latitude"))
        self.le_localTime.setText(_translate("WizzardMainDialog", "00:00:00.00"))
        self.label_7.setText(_translate("WizzardMainDialog", "Local Sidereal Time "))
        self.le_siteLatitude.setText(_translate("WizzardMainDialog", "0000000000"))
        self.label_12.setText(_translate("WizzardMainDialog", "Site Elevation"))
        self.le_horizonLimitHigh.setToolTip(_translate("WizzardMainDialog", "Actual horizon limit for slewing higher bound"))
        self.le_horizonLimitHigh.setInputMask(_translate("WizzardMainDialog", "#99"))
        self.le_horizonLimitHigh.setText(_translate("WizzardMainDialog", "090"))
        self.label_4.setText(_translate("WizzardMainDialog", "HorizLim. Low"))
        self.le_horizonLimitLow.setToolTip(_translate("WizzardMainDialog", "Actual horizon limit for slewing lower bound"))
        self.le_horizonLimitLow.setInputMask(_translate("WizzardMainDialog", "#99"))
        self.le_horizonLimitLow.setText(_translate("WizzardMainDialog", "000"))
        self.label_20.setText(_translate("WizzardMainDialog", "HorizLim High"))
        self.btn_setHorizonLimitLow.setToolTip(_translate("WizzardMainDialog", "Sets the horion limit low"))
        self.btn_setHorizonLimitLow.setText(_translate("WizzardMainDialog", "Set"))
        self.btn_setHorizonLimitHigh.setToolTip(_translate("WizzardMainDialog", "Sets the horizon limit high"))
        self.btn_setHorizonLimitHigh.setText(_translate("WizzardMainDialog", "Set"))
        self.label_58.setText(_translate("WizzardMainDialog", "Coordinates from Mount"))
        self.label_59.setText(_translate("WizzardMainDialog", "Slewing Limits"))
        self.label_16.setText(_translate("WizzardMainDialog", "both axes"))
        self.le_telescopeTempDECMotor.setToolTip(_translate("WizzardMainDialog", "Temperatur of DEC motor in mount"))
        self.le_telescopeTempDECMotor.setText(_translate("WizzardMainDialog", "00.0"))
        self.label_55.setText(_translate("WizzardMainDialog", "Temperature motor driver circuit"))
        self.label_42.setText(_translate("WizzardMainDialog", "°"))
        self.label_60.setText(_translate("WizzardMainDialog", "°"))
        self.label_64.setText(_translate("WizzardMainDialog", "°C"))
        self.label_76.setText(_translate("WizzardMainDialog", "°C"))
        self.le_windSpeedWeather.setToolTip(_translate("WizzardMainDialog", "shows the refraction correction status on / off"))
        self.label_32.setText(_translate("WizzardMainDialog", "WindSpeed"))
        self.label_73.setText(_translate("WizzardMainDialog", "hPa"))
        self.le_temperatureStick.setToolTip(_translate("WizzardMainDialog", "shows the refraction correction status on / off"))
        self.le_temperatureWeather.setToolTip(_translate("WizzardMainDialog", "shows the refraction correction status on / off"))
        self.label_25.setText(_translate("WizzardMainDialog", "DewPoint"))
        self.label_31.setText(_translate("WizzardMainDialog", "Rain Rate"))
        self.le_pressureStick.setToolTip(_translate("WizzardMainDialog", "shows the refraction correction status on / off"))
        self.label_75.setText(_translate("WizzardMainDialog", "hPa"))
        self.label_70.setText(_translate("WizzardMainDialog", "°C"))
        self.label_68.setText(_translate("WizzardMainDialog", "%"))
        self.label_26.setText(_translate("WizzardMainDialog", "Humidity"))
        self.le_refractionTemperature.setToolTip(_translate("WizzardMainDialog", "shows the refraction temperature used in mount"))
        self.le_humidityWeather.setToolTip(_translate("WizzardMainDialog", "shows the refraction correction status on / off"))
        self.le_cloudCoverWeather.setToolTip(_translate("WizzardMainDialog", "shows the refraction correction status on / off"))
        self.label_67.setText(_translate("WizzardMainDialog", "m/s"))
        self.btn_setRefractionParameters.setToolTip(_translate("WizzardMainDialog", "Pushes the refraction temp and pressur to mount"))
        self.btn_setRefractionParameters.setText(_translate("WizzardMainDialog", "Push Parameter Update to Mount Manually"))
        self.le_dewPointWeather.setToolTip(_translate("WizzardMainDialog", "shows the refraction correction status on / off"))
        self.label_71.setText(_translate("WizzardMainDialog", "°C"))
        self.le_windDirectionWeather.setToolTip(_translate("WizzardMainDialog", "shows the refraction correction status on / off"))
        self.label_33.setText(_translate("WizzardMainDialog", "WindDirect."))
        self.label_77.setText(_translate("WizzardMainDialog", "%"))
        self.label_30.setText(_translate("WizzardMainDialog", "CloudCover"))
        self.label_24.setText(_translate("WizzardMainDialog", "Airtemp."))
        self.label_22.setText(_translate("WizzardMainDialog", "Refraction Correction Status is"))
        self.label_74.setText(_translate("WizzardMainDialog", "°C"))
        self.label_27.setText(_translate("WizzardMainDialog", "Pressure"))
        self.label_57.setText(_translate("WizzardMainDialog", "Environment Settings"))
        self.le_dewPointStick.setToolTip(_translate("WizzardMainDialog", "shows the refraction correction status on / off"))
        self.le_refractionPressure.setToolTip(_translate("WizzardMainDialog", "shows the refraction pressure used in mount"))
        self.le_rainRateWeather.setToolTip(_translate("WizzardMainDialog", "shows the refraction correction status on / off"))
        self.label_66.setText(_translate("WizzardMainDialog", "°"))
        self.le_pressureWeather.setToolTip(_translate("WizzardMainDialog", "shows the refraction correction status on / off"))
        self.le_refractionStatus.setToolTip(_translate("WizzardMainDialog", "shows the refraction correction status on / off"))
        self.le_refractionStatus.setText(_translate("WizzardMainDialog", "ON"))
        self.le_humidityStick.setToolTip(_translate("WizzardMainDialog", "shows the refraction correction status on / off"))
        self.label_28.setText(_translate("WizzardMainDialog", "ObsCond"))
        self.label_13.setText(_translate("WizzardMainDialog", "Refraction Mount"))
        self.label_29.setText(_translate("WizzardMainDialog", "OpenWeather"))
        self.label_72.setText(_translate("WizzardMainDialog", "%"))
        self.label_69.setText(_translate("WizzardMainDialog", "%"))
        self.label_78.setText(_translate("WizzardMainDialog", "hPa"))
        self.label_82.setText(_translate("WizzardMainDialog", "m"))
        self.checkAutoRefraction.setToolTip(_translate("WizzardMainDialog", "sets the refraction param updates to automatic"))
        self.checkAutoRefraction.setText(_translate("WizzardMainDialog", "Periodic Parameter Update from Mountwizzard"))
        self.label_86.setText(_translate("WizzardMainDialog", "Refraction Correction in Mount"))
        self.btn_setRefractionCorrection.setToolTip(_translate("WizzardMainDialog", "Sets refraction correction in mount on / off"))
        self.btn_setRefractionCorrection.setText(_translate("WizzardMainDialog", "I/O"))
        self.label_105.setText(_translate("WizzardMainDialog", "deg"))
        self.label_106.setText(_translate("WizzardMainDialog", "deg"))
        self.label_79.setText(_translate("WizzardMainDialog", "°C"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), _translate("WizzardMainDialog", "Site / Mount"))
        self.tabWidget_2.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Configuration of the imaging / plate solving program and the ASCOM drivers</p></body></html>"))
        self.label_41.setText(_translate("WizzardMainDialog", "Directory Images"))
        self.label_122.setText(_translate("WizzardMainDialog", "°"))
        self.btn_selectHorizonPointsFileName.setToolTip(_translate("WizzardMainDialog", "Sets dual tracking on / off"))
        self.btn_selectHorizonPointsFileName.setText(_translate("WizzardMainDialog", "Select"))
        self.label_36.setText(_translate("WizzardMainDialog", "Horizonpoints"))
        self.checkUseMinimumHorizonLine.setToolTip(_translate("WizzardMainDialog", "Use Highspeed download of CCD camera if availabe"))
        self.checkUseMinimumHorizonLine.setText(_translate("WizzardMainDialog", "Altitude as Horizon Line"))
        self.le_imageDirectoryName.setToolTip(_translate("WizzardMainDialog", "Button text park menu 1"))
        self.le_horizonPointsFileName.setToolTip(_translate("WizzardMainDialog", "Button text park menu 1"))
        self.label_35.setText(_translate("WizzardMainDialog", "Modelpoints"))
        self.label_63.setText(_translate("WizzardMainDialog", "Filenames for modeling"))
        self.btn_selectImageDirectoryName.setToolTip(_translate("WizzardMainDialog", "Sets dual tracking on / off"))
        self.btn_selectImageDirectoryName.setText(_translate("WizzardMainDialog", "Select"))
        self.le_modelPointsFileName.setToolTip(_translate("WizzardMainDialog", "Button text park menu 1"))
        self.checkKeepImages.setToolTip(_translate("WizzardMainDialog", "Checked if you would like to keep the images of modeling session"))
        self.checkKeepImages.setText(_translate("WizzardMainDialog", "Keep images from modeling"))
        self.label_180.setText(_translate("WizzardMainDialog", "Altitude"))
        self.btn_selectModelPointsFileName.setToolTip(_translate("WizzardMainDialog", "Sets dual tracking on / off"))
        self.btn_selectModelPointsFileName.setText(_translate("WizzardMainDialog", "Select"))
        self.label_38.setText(_translate("WizzardMainDialog", "Mount Settle Time Modeling"))
        self.label_169.setText(_translate("WizzardMainDialog", "mm"))
        self.label_173.setText(_translate("WizzardMainDialog", "%"))
        self.checkFastDownload.setToolTip(_translate("WizzardMainDialog", "Use Highspeed download of CCD camera if availabe"))
        self.checkFastDownload.setText(_translate("WizzardMainDialog", "Fast Download"))
        self.label_168.setText(_translate("WizzardMainDialog", "Focal Length of Telescope"))
        self.settlingTime.setToolTip(_translate("WizzardMainDialog", "Sets the time to wait after mount stop before imaging"))
        self.isoSetting.setToolTip(_translate("WizzardMainDialog", "Sets the iso setting"))
        self.label_164.setText(_translate("WizzardMainDialog", "s"))
        self.scaleSubframe.setToolTip(_translate("WizzardMainDialog", "Sets the iso setting"))
        self.label_172.setText(_translate("WizzardMainDialog", "ISO Setting"))
        self.label_163.setText(_translate("WizzardMainDialog", "Imaging setup for modeling"))
        self.label_166.setText(_translate("WizzardMainDialog", "Pixel Size x/y for Camera"))
        self.cameraExposure.setToolTip(_translate("WizzardMainDialog", "sets the exposure time"))
        self.label_167.setText(_translate("WizzardMainDialog", "um"))
        self.pixelSize.setToolTip(_translate("WizzardMainDialog", "Pixel size of camera"))
        self.checkDoSubframe.setToolTip(_translate("WizzardMainDialog", "Use Highspeed download of CCD camera if availabe"))
        self.checkDoSubframe.setText(_translate("WizzardMainDialog", "Use Subframe"))
        self.label_39.setText(_translate("WizzardMainDialog", "Exposure Camera"))
        self.focalLength.setToolTip(_translate("WizzardMainDialog", "resulting focal length - please think of reducers etc."))
        self.cameraBin.setToolTip(_translate("WizzardMainDialog", "sets the camera bin"))
        self.label_102.setText(_translate("WizzardMainDialog", "Subframe"))
        self.label_165.setText(_translate("WizzardMainDialog", "s"))
        self.label_40.setText(_translate("WizzardMainDialog", "Camera bin"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_11), _translate("WizzardMainDialog", "Imaging"))
        self.btn_setupAscomCameraDriver.setText(_translate("WizzardMainDialog", "Camera"))
        self.cameraPlateChooser.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Selects the program, which is used for imaging and plat solving</p></body></html>"))
        self.cameraPlateChooser.setTitle(_translate("WizzardMainDialog", "Camera / Plate Solver Chooser"))
        self.rb_cameraSGPro.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p><span style=\" font-size:10pt;\">SGPro for imaging and plate solving</span></p></body></html>"))
        self.rb_cameraSGPro.setText(_translate("WizzardMainDialog", "SGPro"))
        self.rb_cameraTSX.setText(_translate("WizzardMainDialog", "TheSkyX"))
        self.rb_cameraASCOM.setText(_translate("WizzardMainDialog", "ASCOM"))
        self.label_87.setText(_translate("WizzardMainDialog", "ASCOM Camera / PlateSolver Setup"))
        self.btn_setupPlateSolver.setText(_translate("WizzardMainDialog", "PlateSolver"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_13), _translate("WizzardMainDialog", "Imaging / Plate Solver"))
        self.btn_setupStickDriver.setText(_translate("WizzardMainDialog", "ObsCond"))
        self.btn_setupWeatherDriver.setText(_translate("WizzardMainDialog", "Weather"))
        self.btn_setupMountDriver.setText(_translate("WizzardMainDialog", "Mount"))
        self.btn_setupDomeDriver.setText(_translate("WizzardMainDialog", "Dome"))
        self.label_53.setText(_translate("WizzardMainDialog", "ASCOM Drivers Setup"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_12), _translate("WizzardMainDialog", "ASCOM Drivers"))
        self.le_altParkPos3.setInputMask(_translate("WizzardMainDialog", "99"))
        self.le_altParkPos3.setText(_translate("WizzardMainDialog", "1"))
        self.le_parkPos3Text.setToolTip(_translate("WizzardMainDialog", "Button text park menu 3"))
        self.le_parkPos3Text.setText(_translate("WizzardMainDialog", "Dew"))
        self.le_parkPos1Text.setToolTip(_translate("WizzardMainDialog", "Button text park menu 1"))
        self.le_parkPos1Text.setText(_translate("WizzardMainDialog", "Flat West"))
        self.label_19.setText(_translate("WizzardMainDialog", "Az"))
        self.label_43.setText(_translate("WizzardMainDialog", "Az"))
        self.label_54.setText(_translate("WizzardMainDialog", "Fixed Park Positions Setup"))
        self.le_azParkPos3.setInputMask(_translate("WizzardMainDialog", "999"))
        self.le_azParkPos3.setText(_translate("WizzardMainDialog", "270"))
        self.le_parkPos2Text.setToolTip(_translate("WizzardMainDialog", "Button text park menu 2"))
        self.le_parkPos2Text.setText(_translate("WizzardMainDialog", "Flat East"))
        self.le_azParkPos1.setInputMask(_translate("WizzardMainDialog", "999"))
        self.le_azParkPos1.setText(_translate("WizzardMainDialog", "1"))
        self.label_45.setText(_translate("WizzardMainDialog", "Alt"))
        self.le_altParkPos4.setInputMask(_translate("WizzardMainDialog", "99"))
        self.le_altParkPos4.setText(_translate("WizzardMainDialog", "1"))
        self.le_altParkPos1.setInputMask(_translate("WizzardMainDialog", "99"))
        self.le_altParkPos1.setText(_translate("WizzardMainDialog", "89"))
        self.label_2.setText(_translate("WizzardMainDialog", "Button 1    Text"))
        self.le_altParkPos2.setInputMask(_translate("WizzardMainDialog", "99"))
        self.le_altParkPos2.setText(_translate("WizzardMainDialog", "89"))
        self.label_51.setText(_translate("WizzardMainDialog", "Alt"))
        self.label_50.setText(_translate("WizzardMainDialog", "Button 4    Text"))
        self.label_44.setText(_translate("WizzardMainDialog", "Button 2    Text"))
        self.le_azParkPos2.setInputMask(_translate("WizzardMainDialog", "999"))
        self.le_azParkPos2.setText(_translate("WizzardMainDialog", "359"))
        self.label_49.setText(_translate("WizzardMainDialog", "Az"))
        self.label_3.setText(_translate("WizzardMainDialog", "Alt"))
        self.le_azParkPos4.setInputMask(_translate("WizzardMainDialog", "999"))
        self.le_azParkPos4.setText(_translate("WizzardMainDialog", "90"))
        self.label_46.setText(_translate("WizzardMainDialog", "Az"))
        self.label_48.setText(_translate("WizzardMainDialog", "Alt"))
        self.le_parkPos4Text.setToolTip(_translate("WizzardMainDialog", "Button text park menu 4"))
        self.le_parkPos4Text.setText(_translate("WizzardMainDialog", "CCD"))
        self.label_47.setText(_translate("WizzardMainDialog", "Button 3    Text"))
        self.le_azParkPos5.setInputMask(_translate("WizzardMainDialog", "999"))
        self.le_azParkPos5.setText(_translate("WizzardMainDialog", "270"))
        self.label_92.setText(_translate("WizzardMainDialog", "Button 6    Text"))
        self.le_altParkPos6.setInputMask(_translate("WizzardMainDialog", "99"))
        self.le_altParkPos6.setText(_translate("WizzardMainDialog", "1"))
        self.label_93.setText(_translate("WizzardMainDialog", "Az"))
        self.label_94.setText(_translate("WizzardMainDialog", "Alt"))
        self.label_95.setText(_translate("WizzardMainDialog", "Button 5    Text"))
        self.le_altParkPos5.setInputMask(_translate("WizzardMainDialog", "99"))
        self.le_altParkPos5.setText(_translate("WizzardMainDialog", "1"))
        self.le_parkPos6Text.setToolTip(_translate("WizzardMainDialog", "Button text park menu 4"))
        self.le_parkPos6Text.setText(_translate("WizzardMainDialog", "CCD"))
        self.le_parkPos5Text.setToolTip(_translate("WizzardMainDialog", "Button text park menu 3"))
        self.le_parkPos5Text.setText(_translate("WizzardMainDialog", "Dew"))
        self.label_131.setText(_translate("WizzardMainDialog", "Az"))
        self.label_132.setText(_translate("WizzardMainDialog", "Alt"))
        self.le_azParkPos6.setInputMask(_translate("WizzardMainDialog", "999"))
        self.le_azParkPos6.setText(_translate("WizzardMainDialog", "90"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_10), _translate("WizzardMainDialog", "Park Positions"))
        self.btn_downloadEarthrotation.setText(_translate("WizzardMainDialog", "Download Earth Rotation and UTC files"))
        self.label_123.setText(_translate("WizzardMainDialog", "Webservices for space data"))
        self.btn_downloadSpacestations.setText(_translate("WizzardMainDialog", "Download Space Stations TLE Elements"))
        self.btn_downloadSatbrighest.setText(_translate("WizzardMainDialog", "Download Brightest Satellite TLE Elements"))
        self.btn_downloadAsteroids.setText(_translate("WizzardMainDialog", "Download Asteroids MPC File"))
        self.btn_downloadComets.setText(_translate("WizzardMainDialog", "Download Comets MPC File"))
        self.checkEarthrotation.setToolTip(_translate("WizzardMainDialog", "Use Highspeed download of CCD camera if availabe"))
        self.checkEarthrotation.setText(_translate("WizzardMainDialog", "Upload  Earth Rotation and UTC files"))
        self.checkSpacestations.setToolTip(_translate("WizzardMainDialog", "Use Highspeed download of CCD camera if availabe"))
        self.checkSpacestations.setText(_translate("WizzardMainDialog", "Upload Space Stations TLE Elements"))
        self.checkSatellites.setToolTip(_translate("WizzardMainDialog", "Use Highspeed download of CCD camera if availabe"))
        self.checkSatellites.setText(_translate("WizzardMainDialog", "Upload Brightest Satellite TLE Elements"))
        self.checkAsteroids.setToolTip(_translate("WizzardMainDialog", "Use Highspeed download of CCD camera if availabe"))
        self.checkAsteroids.setText(_translate("WizzardMainDialog", "Upload Asteroids MPC File"))
        self.checkComets.setToolTip(_translate("WizzardMainDialog", "Use Highspeed download of CCD camera if availabe"))
        self.checkComets.setText(_translate("WizzardMainDialog", "Upload Comets MPC File"))
        self.btn_uploadMount.setText(_translate("WizzardMainDialog", "Upload to Mount"))
        self.btn_downloadAll.setText(_translate("WizzardMainDialog", "Download All Files"))
        self.label_134.setText(_translate("WizzardMainDialog", "Mount Uploads"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_7), _translate("WizzardMainDialog", "Download Data"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), _translate("WizzardMainDialog", "Settings"))
        self.firmwareProductName_6.setText(_translate("WizzardMainDialog", "HW Version:"))
        self.le_firmwareTime.setText(_translate("WizzardMainDialog", "Firmware Time"))
        self.le_hardwareVersion.setText(_translate("WizzardMainDialog", "Hardware Version"))
        self.le_firmwareProductName.setText(_translate("WizzardMainDialog", "Product Number"))
        self.firmwareProductName_5.setText(_translate("WizzardMainDialog", "FW Time:"))
        self.firmwareProductName_4.setText(_translate("WizzardMainDialog", "FW Date:"))
        self.le_firmwareNumber.setText(_translate("WizzardMainDialog", "Firmware Number"))
        self.firmwareProductName_2.setText(_translate("WizzardMainDialog", "Product:"))
        self.le_firmwareDate.setText(_translate("WizzardMainDialog", "Firmware Date"))
        self.firmwareProductName_3.setText(_translate("WizzardMainDialog", "Firmware:"))
        self.label_56.setText(_translate("WizzardMainDialog", "Product Versions"))
        self.firmwareProductName_7.setText(_translate("WizzardMainDialog", "Working directory of MountWizzard is actually: "))
        self.le_mwWorkingDir.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Here the actually used working directory is shown</p></body></html>"))
        self.le_mwWorkingDir.setText(_translate("WizzardMainDialog", "Diectory Name"))
        self.le_firmwareProductName_2.setText(_translate("WizzardMainDialog", "Mount Wizzard 2 (C) MWORION build"))
        self.build.setText(_translate("WizzardMainDialog", "2.0.7"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("WizzardMainDialog", "Version"))
        self.le_ipRelaybox.setToolTip(_translate("WizzardMainDialog", "IP Adress of relay switch"))
        self.le_ipRelaybox.setText(_translate("WizzardMainDialog", "192.168.2.14"))
        self.btn_bootMount.setToolTip(_translate("WizzardMainDialog", "Boots the mount via Relay switch"))
        self.btn_bootMount.setText(_translate("WizzardMainDialog", "Boot Mount"))
        self.btn_switchHeater.setToolTip(_translate("WizzardMainDialog", "Switches power supply of dew heater "))
        self.btn_switchHeater.setText(_translate("WizzardMainDialog", "Switch Heater"))
        self.btn_switchCCD.setToolTip(_translate("WizzardMainDialog", "Switches Power supply of CCD Camera"))
        self.btn_switchCCD.setText(_translate("WizzardMainDialog", "Switch CCD"))
        self.label_97.setText(_translate("WizzardMainDialog", "IP Relay Box:"))
        self.label_96.setText(_translate("WizzardMainDialog", "Relays"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_9), _translate("WizzardMainDialog", "MW"))
        self.btn_shutdownQuit.setToolTip(_translate("WizzardMainDialog", "Send shutdown command to the mount and quit the tool"))
        self.btn_shutdownQuit.setText(_translate("WizzardMainDialog", "Shutdown / Quit"))
        self.windowTitle.setText(_translate("WizzardMainDialog", "MountWizzard 2"))
        self.btn_mountQuit.setToolTip(_translate("WizzardMainDialog", "Quits the tool and saves the settings data in config.cfg"))
        self.btn_mountQuit.setText(_translate("WizzardMainDialog", "Save / Quit"))
        self.errorStatus.setToolTip(_translate("WizzardMainDialog", "Error Messages from Tool"))
        self.errorStatus.setHtml(_translate("WizzardMainDialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p></body></html>"))
        self.label_104.setText(_translate("WizzardMainDialog", "Message Board:"))
        self.btn_selectClose.setToolTip(_translate("WizzardMainDialog", "Sets dual tracking on / off"))
        self.btn_selectClose.setText(_translate("WizzardMainDialog", "X"))
        self.btn_mountSave.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Saves the settings data in config.cfg</p></body></html>"))
        self.btn_mountSave.setText(_translate("WizzardMainDialog", "Save"))
        self.btn_camPlateConnected.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Status of Camera: green = available and connected</p></body></html>"))
        self.btn_camPlateConnected.setText(_translate("WizzardMainDialog", "Camera"))
        self.btn_domeConnected.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Status of dome: grey: no dome configured</p></body></html>"))
        self.btn_domeConnected.setText(_translate("WizzardMainDialog", "Dome"))
        self.btn_driverMountConnected.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Status of mount</p></body></html>"))
        self.btn_driverMountConnected.setText(_translate("WizzardMainDialog", "Mount"))
        self.btn_driverWeatherConnected.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Status of Open Weather</p></body></html>"))
        self.btn_driverWeatherConnected.setText(_translate("WizzardMainDialog", "Weather"))
        self.btn_driverStickConnected.setToolTip(_translate("WizzardMainDialog", "<html><head/><body><p>Status of Obervation conditions (e.g. Stickstation)</p></body></html>"))
        self.btn_driverStickConnected.setText(_translate("WizzardMainDialog", "ObsCond"))

